# -*- coding: utf-8 -*-
"""
Implementation of 'AuthKey'.
"""
# Import python libs
from typing import cast, Any


class AuthKey:
    """
    The API Key information.
    """
    def __init__(  # pylint: disable=too-many-arguments
            self,
            id_: str,
            name: str
        ) -> None:
        """
        :param id_: The api key id.
        :type id_: str
        :param name: The api key name.
        :type name: str
        """
        self._id = id_
        self._name = name

    @property
    def id(self) -> str:  # pylint: disable=invalid-name
        """
        Get the api key ID.

        :return: The api key ID.
        :rtype: str
        """
        return self._id

    @property
    def name(self) -> str:
        """
        Get the api key name.

        :return: The api key name.
        :rtype: str
        """
        return self._name

    def __eq__(self, other: Any) -> bool:
        """
        Returns whether both objects are equal

        :param other: Other object to compare with.
        :type other: Any
        :return: ``True`` if both objects are equal. ``False``
            otherwise.
        :rtype: bool
        """
        if not isinstance(other, AuthKey):
            return False

        return (
            self.id == cast(AuthKey, other).id and
            self.name == cast(AuthKey, other).name
        )

    def __ne__(self, other: Any) -> bool:
        """
        Returns whether both objects are not equal

        :param other: Other object to compare with.
        :type other: Any
        :return: ``True`` if both objects are not equal. ``False``
            otherwise.
        :rtype: bool
        """
        return not self == other

    def __str__(self) -> str:
        """
        Returns a string representation of this object.

        :return: A string representation of this object.
        :rtype: str
        """
        return 'AuthKey(id={0}, name={1}'.format(self.id, self.name)

    __repr__ = __str__
