# -*- coding: utf-8 -*-
"""
Implementation of 'AuthOrg'.
"""
# Import python libs
from typing import cast, Any


class AuthOrg:
    """
    The organization information of the caller.

    Initially, SLS will only support a single organization.
    """
    def __init__(
            self,
            id_: str,
            name: str,
            owner_id: str
        ) -> None:
        """
        :param id_: The org id.
        :type id_: str
        :param name: The name.
        :type name: str
        :param owner_id: The owner id.
        :type owner_id: str
        """
        self._id = id_
        self._name = name
        self._owner_id = owner_id

    @property
    def id(self) -> str:  # pylint: disable=invalid-name
        """
        Get the org ID.

        :return: The org ID.
        :rtype: str
        """
        return self._id

    @property
    def name(self) -> str:
        """
        Get the name.

        :return: The name.
        :rtype: str
        """
        return self._name

    @property
    def owner_id(self) -> str:
        """
        Get the owner ID.

        :return: The owner ID.
        :rtype: str
        """
        return self._owner_id

    def __eq__(self, other: Any) -> bool:
        """
        Returns whether both objects are equal

        :param other: Other object to compare with.
        :type other: Any
        :return: ``True`` if both objects are equal. ``False``
            otherwise.
        :rtype: bool
        """
        if not isinstance(other, AuthOrg):
            return False

        return (
            self.id == cast(AuthOrg, other).id and
            self.name == cast(AuthOrg, other).name and
            self.owner_id == cast(AuthOrg, other).owner_id
        )

    def __ne__(self, other: Any) -> bool:
        """
        Returns whether both objects are not equal

        :param other: Other object to compare with.
        :type other: Any
        :return: ``True`` if both objects are not equal. ``False``
            otherwise.
        :rtype: bool
        """
        return not self == other

    def __str__(self) -> str:
        """
        Returns a string representation of this object.

        :return: A string representation of this object.
        :rtype: str
        """
        return (
            'AuthOrg(id={0}, name={1}, owner_id={2})'.format(
                self.id, self.name, self.owner_id
            )
        )

    __repr__ = __str__
