# -*- coding: utf-8 -*-
"""
Implementation of 'AuthWorkspace'.
"""
# Import python libs
from typing import cast, Any


class AuthWorkspace:
    """
    The workspace information of the organization.
    """
    def __init__(
            self,
            id_: str,
            name: str,
            enabled: bool,
            is_default: bool
        ) -> None:
        """
        :param id_: The workspace id.
        :type id_: str
        :param name: The workspace name.
        :type name: str
        :param enabled: Whether this workspace is enabled or disabled.
        :type enabled: bool
        :param is_default: Whether this is the default workspace.
        :type is_default: bool
        """
        self._id = id_
        self._name = name
        self._enabled = enabled
        self._is_default = is_default

    @property
    def id(self) -> str:  # pylint: disable=invalid-name
        """
        Get the workspace ID.

        :return: The workspace ID.
        :rtype: str
        """
        return self._id

    @property
    def name(self) -> str:
        """
        Get the workspace name.

        :return: The workspace name.
        :rtype: str
        """
        return self._name

    @property
    def enabled(self) -> bool:
        """
        Get whether this workspace is enabled or disabled.

        :return: ``True`` if this workspace is enabled. ``False`` if it
            is disabled.
        :rtype: bool
        """
        return self._enabled

    @property
    def is_default(self) -> bool:
        """
        Get whether this workspace is enabled or disabled.

        :return: ``True`` if this workspace is the default. ``False``
            otherwise.
        :rtype: bool
        """
        return self._is_default

    def __eq__(self, other: Any) -> bool:
        """
        Returns whether both objects are equal

        :param other: Other object to compare with.
        :type other: Any
        :return: ``True`` if both objects are equal. ``False``
            otherwise.
        :rtype: bool
        """
        if not isinstance(other, AuthWorkspace):
            return False

        return (
            self.id == cast(AuthWorkspace, other).id and
            self.name == cast(AuthWorkspace, other).name and
            self.enabled == cast(AuthWorkspace, other).enabled and
            self.is_default == cast(AuthWorkspace, other).is_default
        )

    def __ne__(self, other: Any) -> bool:
        """
        Returns whether both objects are not equal

        :param other: Other object to compare with.
        :type other: Any
        :return: ``True`` if both objects are not equal. ``False``
            otherwise.
        :rtype: bool
        """
        return not self == other

    def __str__(self) -> str:
        """
        Returns a string representation of this object.

        :return: A string representation of this object.
        :rtype: str
        """
        return (
            'AuthWorkspace(id={0}, name={1}, enabled={2}, is_default={3})'.format(
                self.id, self.name, self.enabled, self.is_default
            )
        )

    __repr__ = __str__
