# -*- coding: utf-8 -*-
"""
Interface class of 'IAuthHandler'.
"""
# Import python libs
import abc

# Import local libs
from systemlink.messagebus.auth.auth_result import AuthResult


class IAuthHandler(metaclass=abc.ABCMeta):  # pylint: disable=too-few-public-methods
    """
    Interface for authenticating based on a given token.
    """
    @abc.abstractmethod
    def auth(self, token: str) -> AuthResult:
        """
        The Auth method takes a token (e.g. apiKey) and authenticates
        the caller.

        :param token: The token to authenticate
        :type token: str
        :return: The AuthResult indicates whether or not the
           authentication of the caller was successful.
        :rtype: AuthResult
        """
        raise NotImplementedError()
