# -*- coding: utf-8 -*-
"""
Implementation of 'NoAuthHandler'.
"""
# Import local libs
from systemlink.messagebus.auth.auth_result import AuthResult
from systemlink.messagebus.auth.i_auth_handler import IAuthHandler


class NoAuthHandler(IAuthHandler):  # pylint: disable=too-few-public-methods
    """
    Auth handler which allows by-passing auth completely.
    It marks auth as succeeded but does not allow access to anything.
    Should only be used for compatibility in places where permissions
    will not be checked.
    """
    def auth(self, token: str) -> AuthResult:
        """
        The Auth method takes a token (e.g. apiKey) and authenticates
        the caller.

        :param token: The token to authenticate
        :type token: str
        :return: The AuthResult indicates whether or not the
           authentication of the caller was successful.
        :rtype: AuthResult
        """
        return AuthResult.create_empty()
