# -*- coding: utf-8 -*-
"""
Implementation of 'PolicyType'.
"""

# Import python libs
from enum import IntEnum


class PolicyType(IntEnum):
    """
    Denotes the intent of a policy.
    """

    # Indicates that the current policy is installed by default.
    Default = 0

    # Indicates that the current policy is for internal use only.
    Internal = 1

    # Indicates that the current policy is used for a custom, external purpose.
    Custom = 2

    # Indicates that the current policy is associated with a role.
    Role = 3

    @classmethod
    def deserialize(cls, content: str):
        """
        Deserializes JSON content into a PolicyType.

        :param content: The content to deserialize.
        :type content: str
        :return: The deserialized type.
        :rtype: PolicyType
        """
        normalized = content.lower()
        for name, member in cls.__members__.items():
            if normalized == name.lower():
                return member
        raise ValueError('Failed to deserialize policy type {0}'.format(content))


    def __str__(self) -> str:
        """
        Returns a string representation of this object.

        :return: A string representation of this object.
        :rtype: str
        """
        return str(self.name).lower()

    __repr__ = __str__
