# -*- coding: utf-8 -*-
"""
Utilities for managing webserver users.
"""

# Import python libs
import re
from typing import Optional


def path_normalize_remote_user(remote_user: Optional[str]) -> Optional[str]:
    """
    Normalizes an Apache remote-user to be compatible with a filesystem path.

    :param remote_user: The remote-user to normalize.
    :type remote_user: Optional[str]
    :return: The normalized remote-user.
    :rtype: Optional[str]
    """
    if remote_user is None:
        return remote_user
    return re.sub(r'[ $&`:<>[\]{}\"+#%@/;=?\\^|~‘,]', '_', remote_user)
