# -*- coding: utf-8 -*-
# DO NOT EDIT! This file is auto-generated.
"""
Classes for SystemLink Message Bus usage.
"""
# Import python libs
import json
import sys
from datetime import datetime  # pylint: disable=unused-import
from typing import cast, Any, Dict, List, Optional, Union  # pylint: disable=unused-import

# Import local libs
from systemlink.messagebus.broadcast_message import BroadcastMessage  # pylint: disable=unused-import
from systemlink.messagebus.datetime import from_datetime, to_datetime  # pylint: disable=unused-import
from systemlink.messagebus.generic_message import GenericMessage  # pylint: disable=unused-import
from systemlink.messagebus.message_header import (  # pylint: disable=unused-import
    MessageHeader, JSON_MESSAGE_CONTENT_TYPE, BINARY_MESSAGE_CONTENT_TYPE)
from systemlink.messagebus.message_base import MessageBase
from systemlink.messagebus.request_message import RequestMessage  # pylint: disable=unused-import
from systemlink.messagebus.response_message import ResponseMessage  # pylint: disable=unused-import
from systemlink.messagebus.routed_message import RoutedMessage  # pylint: disable=unused-import

_PASS_THROUGH_TYPES = {
    'bool',
    'bytes',
    'float',
    'int',
    'object',
    'str'
}

_PRIMITIVE_TYPES = {
    'bool': bool,
    'bytes': bytes,
    'datetime': datetime,
    'dict': dict,
    'float': float,
    'int': int,
    'list': list,
    'object': object,
    'str': str
}


def _str_to_type(type_name: str) -> type:
    """
    Convert a type name to a type.

    :param type_name: The name of the type.
    :type type_name: str
    :return: The corresponding type.
    :rtype: type
    """
    type_ = _PRIMITIVE_TYPES.get(type_name)
    if type_ is not None:
        return type_
    return getattr(sys.modules[__name__], type_name)


def _deserialize(value: Any, type_name: str) -> Any:  # pylint: disable=too-many-return-statements,too-many-branches
    """
    Deserialize a value from a Python native type.

    :param value: The value to deserialize.
    :type value: Any
    :param type_name: The name of the type of `value``.
    :type type_name: str
    :return: The deserialized object.
    :rtype: Any
    """
    if value is None:
        return None
    if not type_name:
        return value
    if type_name.endswith(']'):
        sep_index = type_name.find('[')
        sub_type_name = type_name[sep_index+1:-1]
        type_name = type_name[:sep_index]
        if type_name in ('list', 'List'):
            if sub_type_name in _PASS_THROUGH_TYPES:
                return value
            return [_deserialize(item, sub_type_name) for item in value]
        assert type_name in ('dict', 'Dict')
        sep_index = sub_type_name.find(',')
        key_type_name = sub_type_name[:sep_index]
        value_type_name = sub_type_name[sep_index+1:].strip()
        if key_type_name in _PASS_THROUGH_TYPES and value_type_name in _PASS_THROUGH_TYPES:
            return value
        new_dict = {}
        for dict_key, dict_value in value.items():
            new_dict[_deserialize(dict_key, key_type_name)] = _deserialize(
                dict_value, value_type_name
            )
        return new_dict
    if type_name in _PASS_THROUGH_TYPES:
        return value
    type_ = _str_to_type(type_name)
    if type_ == datetime:
        if not isinstance(value, datetime):
            return to_datetime(value)
        return value
    if hasattr(type_, 'from_dict'):
        return type_.from_dict(value)  # type: ignore
    if hasattr(type_, 'from_string'):
        if isinstance(value, int):
            return type_(value)
        return type_.from_string(value)  # type: ignore
    if hasattr(type_, 'from_list'):
        if isinstance(value, int):
            return type_(value)
        return type_.from_list(value)  # type: ignore
    return value


def _serialize(value: Any) -> Any:  # pylint: disable=too-many-return-statements
    """
    Serialize a value to a Python native type.

    :param value: The value to serialize.
    :type value: Any
    :return: The serialized object.
    :rtype: Any
    """
    if value is None:
        return None
    if isinstance(value, list):
        return [_serialize(item) for item in value]
    if isinstance(value, dict):
        new_dict = {}
        for dict_key, dict_value in value.items():
            new_dict[_serialize(dict_key)] = _serialize(dict_value)
        return new_dict
    if isinstance(value, datetime):
        return from_datetime(value)
    if hasattr(value, 'to_dict'):
        return value.to_dict()
    if hasattr(value, 'to_string'):
        return value.to_string()
    if hasattr(value, 'to_list'):
        return value.to_list()
    return value


# pylint: disable=line-too-long,too-many-lines,too-many-instance-attributes,too-many-arguments,too-many-locals,useless-object-inheritance


#
# Configuration service
#


class SectionKeyValues:
    """
    SectionKeyValues custom data type.
    """
    def __init__(
            self,
            section_=None,
            key_values_=None
        ) -> None:
        """
        :param section_: section
        :type section_: str
        :param key_values_: key_values
        :type key_values_: Dict[str, str]
        """
        self.section = section_
        self.key_values = key_values_

    @classmethod
    def from_dict(cls, body_dict: Dict[str, Any]) -> 'SectionKeyValues':
        """
        Create a new instance of :class:`SectionKeyValues` using a dictionary.

        :param body_dict: A dictionary representing the body.
        :type body_dict: dict
        :return: A new instance of :class:`SectionKeyValues`.
        :rtype: SectionKeyValues
        """
        section_ = _deserialize(body_dict.get('section'), 'str')
        key_values_ = _deserialize(body_dict.get('keyValues'), 'Dict[str, str]')
        return cls(
            section_=section_,
            key_values_=key_values_
        )

    @classmethod
    def from_json(cls, body_json: str) -> 'SectionKeyValues':
        """
        Create a new instance of :class:`SectionKeyValues` using a JSON string.

        :param body_json: A string in JSON format representing the body.
        :type body_json: str
        :return: A new instance of :class:`SectionKeyValues`.
        :rtype: SectionKeyValues
        """
        body_dict = cast(Dict[str, Any], json.loads(body_json))
        return cls.from_dict(body_dict)

    @classmethod
    def from_body_bytes(cls, body_bytes: Union[bytes, bytearray]) -> 'SectionKeyValues':
        """
        Create a new instance of :class:`SectionKeyValues` using a body
        of type :class:`bytes` or :class:`bytearray`.

        :param body_bytes: The body to use.
        :type body_bytes: Union[bytes, bytearray]
        :return: A new instance of :class:`SectionKeyValues`.
        :rtype: SectionKeyValues
        """
        body_json = str(body_bytes, 'utf-8')
        return cls.from_json(body_json)

    def to_dict(self) -> Dict[str, Any]:
        """
        Returns a dictionary representing the data in this object.

        :return: A dictionary representing the data in this object.
        :rtype: Dict[str, Any]
        """
        section_ = _serialize(self.section)
        key_values_ = _serialize(self.key_values)
        return {
            'section': section_,
            'keyValues': key_values_
        }

    def to_json(self) -> str:
        """
        Returns a JSON string representing the data in this object.

        :return: A JSON string representing the data in this object.
        :rtype: str
        """
        body_dict = self.to_dict()
        return json.dumps(body_dict, separators=(',', ':'))

    def to_body_bytes(self) -> bytes:
        """
        Returns a :class:`bytes` body representing the data in this object.

        :return: A :class:`bytes` body representing the data in this object.
        :rtype: bytes
        """
        body_json = self.to_json()
        return bytes(body_json, 'utf-8')


class ConfigurationGetKeysRequest(RequestMessage):
    """
    ConfigurationGetKeysRequest JSON request message.
    """
    MESSAGE_NAME = 'ConfigurationGetKeysRequest'

    def __init__(
            self,
            section_=None
        ) -> None:
        """
        :param section_: section
        :type section_: str
        """
        self.section = section_
        header = MessageHeader()
        header.message_name = self.MESSAGE_NAME
        header.content_type = JSON_MESSAGE_CONTENT_TYPE
        routing_key = MessageHeader.generate_routing_key('Configuration', self.MESSAGE_NAME)
        header.routing_key = routing_key
        super().__init__(header, None)

    @classmethod
    def from_dict(cls, body_dict: Dict[str, Any]) -> 'ConfigurationGetKeysRequest':
        """
        Create a new instance of :class:`ConfigurationGetKeysRequest` using a dictionary.

        :param body_dict: The body as a dictionary.
        :type body_dict: Dict[str, Any]
        :return: A new instance of :class:`ConfigurationGetKeysRequest`.
        :rtype: ConfigurationGetKeysRequest
        """
        section_ = _deserialize(body_dict.get('section'), 'str')
        return cls(
            section_=section_
        )

    @classmethod
    def from_json(cls, body_json: str) -> 'ConfigurationGetKeysRequest':
        """
        Create a new instance of :class:`ConfigurationGetKeysRequest` using a JSON string.

        :param body_json: A string in JSON format representing the body.
        :type body_json: str
        :return: A new instance of :class:`ConfigurationGetKeysRequest`.
        :rtype: ConfigurationGetKeysRequest
        """
        body_dict = cast(Dict[str, Any], json.loads(body_json))
        return cls.from_dict(body_dict)

    @classmethod
    def from_body_bytes(cls, body_bytes: Union[bytes, bytearray]) -> 'ConfigurationGetKeysRequest':
        """
        Create a new instance of :class:`ConfigurationGetKeysRequest` using a body
        of type :class:`bytes` or :class:`bytearray`,

        :param body_bytes: The body to use.
        :type body_bytes: Union[bytes, bytearray]
        :return: A new instance of :class:`ConfigurationGetKeysRequest`.
        :rtype: ConfigurationGetKeysRequest
        """
        body_json = str(body_bytes, 'utf-8')
        return cls.from_json(body_json)

    @classmethod
    def from_message(cls, message: GenericMessage) -> 'ConfigurationGetKeysRequest':
        """
        Create a new instance of :class`ConfigurationGetKeysRequest` using a
        :class:`systemlink.messagebus.message_base.MessageBase` derived message.

        :param message: The message to use as the basis for this class instance.
        :type message: GenericMessage
        :return: A new instance of :class`ConfigurationGetKeysRequest`.
        :rtype: ConfigurationGetKeysRequest
        """
        instance = cls.from_body_bytes(message.body_bytes)
        instance.correlation_id = message.correlation_id
        instance.reply_to = message.reply_to
        return instance

    def to_dict(self) -> Dict[str, Any]:
        """
        Returns a dictionary representing the data in this object.

        :return: A dictionary representing the data in this object.
        :rtype: Dict[str, Any]
        """
        section_ = _serialize(self.section)
        return {
            'section': section_
        }

    def to_json(self) -> str:
        """
        Returns a JSON string representing the data in this object.

        :return: A JSON string representing the data in this object.
        :rtype: str
        """
        body_dict = self.to_dict()
        return json.dumps(body_dict, separators=(',', ':'))

    def to_body_bytes(self) -> bytes:
        """
        Returns a :class:`bytes` body representing the data in this object.

        :return: A :class:`bytes` body representing the data in this object.
        :rtype: bytes
        """
        body_json = self.to_json()
        return bytes(body_json, 'utf-8')

    def to_message(self, request_message: Optional[GenericMessage] = None) -> GenericMessage:
        """
        Returns a :class:`systemlink.messagebus.generic_message.GenericMessage`
        object representing the data in this object.

        :param request_message: Request message if this is a response.
        :type request_message: Optional[GenericMessage]
        :return: A :class:`systemlink.messagebus.generic_message.GenericMessage`
            object representing the data in this object.
        :rtype: GenericMessage
        """
        header = self.header
        if request_message:
            request_header = request_message.header
            header.correlation_id = request_header.correlation_id
        body_bytes = self.to_body_bytes()
        return GenericMessage(header, body_bytes)

    @property
    def body_bytes(self) -> bytes:
        """
        Returns a :class:`bytes` body representing the data in this object.

        :return: A :class:`bytes` body representing the data in this object.
        :rtype: bytes
        """
        self._body = self.to_body_bytes()  # pylint: disable=attribute-defined-outside-init
        return self._body

    @body_bytes.setter
    def body_bytes(self, body_bytes: Optional[bytes]) -> None:  # pylint: disable=no-self-use,unused-argument
        """
        Set the raw message body.

        Not implemented. Do not use!

        :param body_bytes: The raw message body.
        :type body_bytes: Optional[bytes]
        """
        # This class method is defined simply because it is defined in
        # the base class.
        raise NotImplementedError("ConfigurationGetKeysRequest does not support setting 'body_bytes'")


class ConfigurationGetKeysResponse(ResponseMessage):
    """
    ConfigurationGetKeysResponse JSON response message.
    """
    MESSAGE_NAME = 'ConfigurationGetKeysResponse'

    def __init__(
            self,
            request_message: Optional[Union[GenericMessage, MessageBase]],
            keys_=None
        ) -> None:
        """
        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: Optional[Union[GenericMessage, MessageBase]]
        :param keys_: keys
        :type keys_: Dict[str, str]
        """
        self.keys = keys_
        header = MessageHeader()
        header.message_name = self.MESSAGE_NAME
        header.content_type = JSON_MESSAGE_CONTENT_TYPE
        # If request_message is None, routing key needs to be set outside this constructor.
        if request_message:
            header.correlation_id = request_message.correlation_id
            routing_key = MessageHeader.generate_routing_key(request_message.reply_to, self.MESSAGE_NAME)
            header.routing_key = routing_key
        super().__init__(header, None)

    @classmethod
    def from_dict(
            cls,
            request_message: Optional[Union[GenericMessage, MessageBase]],
            body_dict: Dict[str, Any]
        ) -> 'ConfigurationGetKeysResponse':
        """
        Create a new instance of :class:`ConfigurationGetKeysResponse` using a dictionary.

        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: Optional[Union[GenericMessage, MessageBase]]
        :param body_dict: The body as a dictionary.
        :type body_dict: Dict[str, Any]
        :return: A new instance of :class:`ConfigurationGetKeysResponse`.
        :rtype: ConfigurationGetKeysResponse
        """
        keys_ = _deserialize(body_dict.get('keys'), 'Dict[str, str]')
        return cls(
            request_message,
            keys_=keys_
        )

    @classmethod
    def from_json(
            cls,
            request_message: Optional[Union[GenericMessage, MessageBase]],
            body_json: str
        ) -> 'ConfigurationGetKeysResponse':
        """
        Create a new instance of :class:`ConfigurationGetKeysResponse` using a JSON string.

        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: Optional[Union[GenericMessage, MessageBase]]
        :param body_json: A string in JSON format representing the body.
        :type body_json: str
        :return: A new instance of :class:`ConfigurationGetKeysResponse`.
        :rtype: ConfigurationGetKeysResponse
        """
        body_dict = cast(Dict[str, Any], json.loads(body_json))
        return cls.from_dict(request_message, body_dict)

    @classmethod
    def from_body_bytes(
            cls,
            request_message: Optional[Union[GenericMessage, MessageBase]],
            body_bytes: Union[bytes, bytearray]
        ) -> 'ConfigurationGetKeysResponse':
        """
        Create a new instance of :class:`ConfigurationGetKeysResponse` using a body
        of type :class:`bytes` or :class:`bytearray`,

        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: Optional[Union[GenericMessage, MessageBase]]
        :param body_bytes: The body to use.
        :type body_bytes: Union[bytes, bytearray]
        :return: A new instance of :class:`ConfigurationGetKeysResponse`.
        :rtype: ConfigurationGetKeysResponse
        """
        body_json = str(body_bytes, 'utf-8')
        return cls.from_json(request_message, body_json)

    @classmethod
    def from_message(cls, message: GenericMessage) -> 'ConfigurationGetKeysResponse':
        """
        Create a new instance of :class`ConfigurationGetKeysResponse` using a
        :class:`systemlink.messagebus.message_base.MessageBase` derived message.

        :param message: The message to use as the basis for this class instance.
        :type message: GenericMessage
        :return: A new instance of :class`ConfigurationGetKeysResponse`.
        :rtype: ConfigurationGetKeysResponse
        """
        instance = cls.from_body_bytes(message, message.body_bytes)
        instance.correlation_id = message.correlation_id
        instance.reply_to = message.reply_to
        routing_key = MessageHeader.generate_routing_key(message.reply_to, cls.MESSAGE_NAME)
        instance.routing_key = routing_key
        return instance

    def to_dict(self) -> Dict[str, Any]:
        """
        Returns a dictionary representing the data in this object.

        :return: A dictionary representing the data in this object.
        :rtype: Dict[str, Any]
        """
        keys_ = _serialize(self.keys)
        return {
            'keys': keys_
        }

    def to_json(self) -> str:
        """
        Returns a JSON string representing the data in this object.

        :return: A JSON string representing the data in this object.
        :rtype: str
        """
        body_dict = self.to_dict()
        return json.dumps(body_dict, separators=(',', ':'))

    def to_body_bytes(self) -> bytes:
        """
        Returns a :class:`bytes` body representing the data in this object.

        :return: A :class:`bytes` body representing the data in this object.
        :rtype: bytes
        """
        body_json = self.to_json()
        return bytes(body_json, 'utf-8')

    def to_message(self, request_message: Optional[GenericMessage] = None) -> GenericMessage:
        """
        Returns a :class:`systemlink.messagebus.generic_message.GenericMessage`
        object representing the data in this object.

        :param request_message: Request message if this is a response.
        :type request_message: Optional[GenericMessage]
        :return: A :class:`systemlink.messagebus.generic_message.GenericMessage`
            object representing the data in this object.
        :rtype: GenericMessage
        """
        header = self.header
        if request_message:
            request_header = request_message.header
            header.correlation_id = request_header.correlation_id
            routing_key = MessageHeader.generate_routing_key(request_header.reply_to, self.MESSAGE_NAME)
            header.routing_key = routing_key
        body_bytes = self.to_body_bytes()
        return GenericMessage(header, body_bytes)

    @property
    def body_bytes(self) -> bytes:
        """
        Returns a :class:`bytes` body representing the data in this object.

        :return: A :class:`bytes` body representing the data in this object.
        :rtype: bytes
        """
        self._body = self.to_body_bytes()  # pylint: disable=attribute-defined-outside-init
        return self._body

    @body_bytes.setter
    def body_bytes(self, body_bytes: Optional[bytes]) -> None:  # pylint: disable=no-self-use,unused-argument
        """
        Set the raw message body.

        Not implemented. Do not use!

        :param body_bytes: The raw message body.
        :type body_bytes: Optional[bytes]
        """
        # This class method is defined simply because it is defined in
        # the base class.
        raise NotImplementedError("ConfigurationGetKeysResponse does not support setting 'body_bytes'")


class ConfigurationSetKeysRequest(RequestMessage):
    """
    ConfigurationSetKeysRequest JSON request message.
    """
    MESSAGE_NAME = 'ConfigurationSetKeysRequest'

    def __init__(
            self,
            user_=None,
            section_=None,
            keys_=None
        ) -> None:
        """
        :param user_: user
        :type user_: str
        :param section_: section
        :type section_: str
        :param keys_: keys
        :type keys_: Dict[str, str]
        """
        self.user = user_
        self.section = section_
        self.keys = keys_
        header = MessageHeader()
        header.message_name = self.MESSAGE_NAME
        header.content_type = JSON_MESSAGE_CONTENT_TYPE
        routing_key = MessageHeader.generate_routing_key('Configuration', self.MESSAGE_NAME)
        header.routing_key = routing_key
        super().__init__(header, None)

    @classmethod
    def from_dict(cls, body_dict: Dict[str, Any]) -> 'ConfigurationSetKeysRequest':
        """
        Create a new instance of :class:`ConfigurationSetKeysRequest` using a dictionary.

        :param body_dict: The body as a dictionary.
        :type body_dict: Dict[str, Any]
        :return: A new instance of :class:`ConfigurationSetKeysRequest`.
        :rtype: ConfigurationSetKeysRequest
        """
        user_ = _deserialize(body_dict.get('user'), 'str')
        section_ = _deserialize(body_dict.get('section'), 'str')
        keys_ = _deserialize(body_dict.get('keys'), 'Dict[str, str]')
        return cls(
            user_=user_,
            section_=section_,
            keys_=keys_
        )

    @classmethod
    def from_json(cls, body_json: str) -> 'ConfigurationSetKeysRequest':
        """
        Create a new instance of :class:`ConfigurationSetKeysRequest` using a JSON string.

        :param body_json: A string in JSON format representing the body.
        :type body_json: str
        :return: A new instance of :class:`ConfigurationSetKeysRequest`.
        :rtype: ConfigurationSetKeysRequest
        """
        body_dict = cast(Dict[str, Any], json.loads(body_json))
        return cls.from_dict(body_dict)

    @classmethod
    def from_body_bytes(cls, body_bytes: Union[bytes, bytearray]) -> 'ConfigurationSetKeysRequest':
        """
        Create a new instance of :class:`ConfigurationSetKeysRequest` using a body
        of type :class:`bytes` or :class:`bytearray`,

        :param body_bytes: The body to use.
        :type body_bytes: Union[bytes, bytearray]
        :return: A new instance of :class:`ConfigurationSetKeysRequest`.
        :rtype: ConfigurationSetKeysRequest
        """
        body_json = str(body_bytes, 'utf-8')
        return cls.from_json(body_json)

    @classmethod
    def from_message(cls, message: GenericMessage) -> 'ConfigurationSetKeysRequest':
        """
        Create a new instance of :class`ConfigurationSetKeysRequest` using a
        :class:`systemlink.messagebus.message_base.MessageBase` derived message.

        :param message: The message to use as the basis for this class instance.
        :type message: GenericMessage
        :return: A new instance of :class`ConfigurationSetKeysRequest`.
        :rtype: ConfigurationSetKeysRequest
        """
        instance = cls.from_body_bytes(message.body_bytes)
        instance.correlation_id = message.correlation_id
        instance.reply_to = message.reply_to
        return instance

    def to_dict(self) -> Dict[str, Any]:
        """
        Returns a dictionary representing the data in this object.

        :return: A dictionary representing the data in this object.
        :rtype: Dict[str, Any]
        """
        user_ = _serialize(self.user)
        section_ = _serialize(self.section)
        keys_ = _serialize(self.keys)
        return {
            'user': user_,
            'section': section_,
            'keys': keys_
        }

    def to_json(self) -> str:
        """
        Returns a JSON string representing the data in this object.

        :return: A JSON string representing the data in this object.
        :rtype: str
        """
        body_dict = self.to_dict()
        return json.dumps(body_dict, separators=(',', ':'))

    def to_body_bytes(self) -> bytes:
        """
        Returns a :class:`bytes` body representing the data in this object.

        :return: A :class:`bytes` body representing the data in this object.
        :rtype: bytes
        """
        body_json = self.to_json()
        return bytes(body_json, 'utf-8')

    def to_message(self, request_message: Optional[GenericMessage] = None) -> GenericMessage:
        """
        Returns a :class:`systemlink.messagebus.generic_message.GenericMessage`
        object representing the data in this object.

        :param request_message: Request message if this is a response.
        :type request_message: Optional[GenericMessage]
        :return: A :class:`systemlink.messagebus.generic_message.GenericMessage`
            object representing the data in this object.
        :rtype: GenericMessage
        """
        header = self.header
        if request_message:
            request_header = request_message.header
            header.correlation_id = request_header.correlation_id
        body_bytes = self.to_body_bytes()
        return GenericMessage(header, body_bytes)

    @property
    def body_bytes(self) -> bytes:
        """
        Returns a :class:`bytes` body representing the data in this object.

        :return: A :class:`bytes` body representing the data in this object.
        :rtype: bytes
        """
        self._body = self.to_body_bytes()  # pylint: disable=attribute-defined-outside-init
        return self._body

    @body_bytes.setter
    def body_bytes(self, body_bytes: Optional[bytes]) -> None:  # pylint: disable=no-self-use,unused-argument
        """
        Set the raw message body.

        Not implemented. Do not use!

        :param body_bytes: The raw message body.
        :type body_bytes: Optional[bytes]
        """
        # This class method is defined simply because it is defined in
        # the base class.
        raise NotImplementedError("ConfigurationSetKeysRequest does not support setting 'body_bytes'")


class ConfigurationSetKeysResponse(ResponseMessage):
    """
    ConfigurationSetKeysResponse JSON response message.
    """
    MESSAGE_NAME = 'ConfigurationSetKeysResponse'

    def __init__(
            self,
            request_message: Optional[Union[GenericMessage, MessageBase]]
        ) -> None:
        header = MessageHeader()
        header.message_name = self.MESSAGE_NAME
        header.content_type = JSON_MESSAGE_CONTENT_TYPE
        # If request_message is None, routing key needs to be set outside this constructor.
        if request_message:
            header.correlation_id = request_message.correlation_id
            routing_key = MessageHeader.generate_routing_key(request_message.reply_to, self.MESSAGE_NAME)
            header.routing_key = routing_key
        super().__init__(header, None)

    @classmethod
    def from_dict(  # pylint: disable=unused-argument
            cls,
            request_message: Optional[Union[GenericMessage, MessageBase]],
            body_dict: Dict[str, Any]
        ) -> 'ConfigurationSetKeysResponse':
        """
        Create a new instance of :class:`ConfigurationSetKeysResponse` using a dictionary.

        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: Optional[Union[GenericMessage, MessageBase]]
        :param body_dict: The body as a dictionary.
        :type body_dict: Dict[str, Any]
        :return: A new instance of :class:`ConfigurationSetKeysResponse`.
        :rtype: ConfigurationSetKeysResponse
        """
        return cls(
            request_message
        )

    @classmethod
    def from_json(
            cls,
            request_message: Optional[Union[GenericMessage, MessageBase]],
            body_json: str
        ) -> 'ConfigurationSetKeysResponse':
        """
        Create a new instance of :class:`ConfigurationSetKeysResponse` using a JSON string.

        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: Optional[Union[GenericMessage, MessageBase]]
        :param body_json: A string in JSON format representing the body.
        :type body_json: str
        :return: A new instance of :class:`ConfigurationSetKeysResponse`.
        :rtype: ConfigurationSetKeysResponse
        """
        body_dict = cast(Dict[str, Any], json.loads(body_json))
        return cls.from_dict(request_message, body_dict)

    @classmethod
    def from_body_bytes(
            cls,
            request_message: Optional[Union[GenericMessage, MessageBase]],
            body_bytes: Union[bytes, bytearray]
        ) -> 'ConfigurationSetKeysResponse':
        """
        Create a new instance of :class:`ConfigurationSetKeysResponse` using a body
        of type :class:`bytes` or :class:`bytearray`,

        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: Optional[Union[GenericMessage, MessageBase]]
        :param body_bytes: The body to use.
        :type body_bytes: Union[bytes, bytearray]
        :return: A new instance of :class:`ConfigurationSetKeysResponse`.
        :rtype: ConfigurationSetKeysResponse
        """
        body_json = str(body_bytes, 'utf-8')
        return cls.from_json(request_message, body_json)

    @classmethod
    def from_message(cls, message: GenericMessage) -> 'ConfigurationSetKeysResponse':
        """
        Create a new instance of :class`ConfigurationSetKeysResponse` using a
        :class:`systemlink.messagebus.message_base.MessageBase` derived message.

        :param message: The message to use as the basis for this class instance.
        :type message: GenericMessage
        :return: A new instance of :class`ConfigurationSetKeysResponse`.
        :rtype: ConfigurationSetKeysResponse
        """
        instance = cls.from_body_bytes(message, message.body_bytes)
        instance.correlation_id = message.correlation_id
        instance.reply_to = message.reply_to
        routing_key = MessageHeader.generate_routing_key(message.reply_to, cls.MESSAGE_NAME)
        instance.routing_key = routing_key
        return instance

    def to_dict(self) -> Dict[str, Any]:  # pylint: disable=no-self-use
        """
        Returns a dictionary representing the data in this object.

        :return: A dictionary representing the data in this object.
        :rtype: Dict[str, Any]
        """
        return {
        }

    def to_json(self) -> str:
        """
        Returns a JSON string representing the data in this object.

        :return: A JSON string representing the data in this object.
        :rtype: str
        """
        body_dict = self.to_dict()
        return json.dumps(body_dict, separators=(',', ':'))

    def to_body_bytes(self) -> bytes:
        """
        Returns a :class:`bytes` body representing the data in this object.

        :return: A :class:`bytes` body representing the data in this object.
        :rtype: bytes
        """
        body_json = self.to_json()
        return bytes(body_json, 'utf-8')

    def to_message(self, request_message: Optional[GenericMessage] = None) -> GenericMessage:
        """
        Returns a :class:`systemlink.messagebus.generic_message.GenericMessage`
        object representing the data in this object.

        :param request_message: Request message if this is a response.
        :type request_message: Optional[GenericMessage]
        :return: A :class:`systemlink.messagebus.generic_message.GenericMessage`
            object representing the data in this object.
        :rtype: GenericMessage
        """
        header = self.header
        if request_message:
            request_header = request_message.header
            header.correlation_id = request_header.correlation_id
            routing_key = MessageHeader.generate_routing_key(request_header.reply_to, self.MESSAGE_NAME)
            header.routing_key = routing_key
        body_bytes = self.to_body_bytes()
        return GenericMessage(header, body_bytes)

    @property
    def body_bytes(self) -> bytes:
        """
        Returns a :class:`bytes` body representing the data in this object.

        :return: A :class:`bytes` body representing the data in this object.
        :rtype: bytes
        """
        self._body = self.to_body_bytes()  # pylint: disable=attribute-defined-outside-init
        return self._body

    @body_bytes.setter
    def body_bytes(self, body_bytes: Optional[bytes]) -> None:  # pylint: disable=no-self-use,unused-argument
        """
        Set the raw message body.

        Not implemented. Do not use!

        :param body_bytes: The raw message body.
        :type body_bytes: Optional[bytes]
        """
        # This class method is defined simply because it is defined in
        # the base class.
        raise NotImplementedError("ConfigurationSetKeysResponse does not support setting 'body_bytes'")


class ConfigurationGetValueRequest(RequestMessage):
    """
    ConfigurationGetValueRequest JSON request message.
    """
    MESSAGE_NAME = 'ConfigurationGetValueRequest'

    def __init__(
            self,
            section_=None,
            key_=None
        ) -> None:
        """
        :param section_: section
        :type section_: str
        :param key_: key
        :type key_: str
        """
        self.section = section_
        self.key = key_
        header = MessageHeader()
        header.message_name = self.MESSAGE_NAME
        header.content_type = JSON_MESSAGE_CONTENT_TYPE
        routing_key = MessageHeader.generate_routing_key('Configuration', self.MESSAGE_NAME)
        header.routing_key = routing_key
        super().__init__(header, None)

    @classmethod
    def from_dict(cls, body_dict: Dict[str, Any]) -> 'ConfigurationGetValueRequest':
        """
        Create a new instance of :class:`ConfigurationGetValueRequest` using a dictionary.

        :param body_dict: The body as a dictionary.
        :type body_dict: Dict[str, Any]
        :return: A new instance of :class:`ConfigurationGetValueRequest`.
        :rtype: ConfigurationGetValueRequest
        """
        section_ = _deserialize(body_dict.get('section'), 'str')
        key_ = _deserialize(body_dict.get('key'), 'str')
        return cls(
            section_=section_,
            key_=key_
        )

    @classmethod
    def from_json(cls, body_json: str) -> 'ConfigurationGetValueRequest':
        """
        Create a new instance of :class:`ConfigurationGetValueRequest` using a JSON string.

        :param body_json: A string in JSON format representing the body.
        :type body_json: str
        :return: A new instance of :class:`ConfigurationGetValueRequest`.
        :rtype: ConfigurationGetValueRequest
        """
        body_dict = cast(Dict[str, Any], json.loads(body_json))
        return cls.from_dict(body_dict)

    @classmethod
    def from_body_bytes(cls, body_bytes: Union[bytes, bytearray]) -> 'ConfigurationGetValueRequest':
        """
        Create a new instance of :class:`ConfigurationGetValueRequest` using a body
        of type :class:`bytes` or :class:`bytearray`,

        :param body_bytes: The body to use.
        :type body_bytes: Union[bytes, bytearray]
        :return: A new instance of :class:`ConfigurationGetValueRequest`.
        :rtype: ConfigurationGetValueRequest
        """
        body_json = str(body_bytes, 'utf-8')
        return cls.from_json(body_json)

    @classmethod
    def from_message(cls, message: GenericMessage) -> 'ConfigurationGetValueRequest':
        """
        Create a new instance of :class`ConfigurationGetValueRequest` using a
        :class:`systemlink.messagebus.message_base.MessageBase` derived message.

        :param message: The message to use as the basis for this class instance.
        :type message: GenericMessage
        :return: A new instance of :class`ConfigurationGetValueRequest`.
        :rtype: ConfigurationGetValueRequest
        """
        instance = cls.from_body_bytes(message.body_bytes)
        instance.correlation_id = message.correlation_id
        instance.reply_to = message.reply_to
        return instance

    def to_dict(self) -> Dict[str, Any]:
        """
        Returns a dictionary representing the data in this object.

        :return: A dictionary representing the data in this object.
        :rtype: Dict[str, Any]
        """
        section_ = _serialize(self.section)
        key_ = _serialize(self.key)
        return {
            'section': section_,
            'key': key_
        }

    def to_json(self) -> str:
        """
        Returns a JSON string representing the data in this object.

        :return: A JSON string representing the data in this object.
        :rtype: str
        """
        body_dict = self.to_dict()
        return json.dumps(body_dict, separators=(',', ':'))

    def to_body_bytes(self) -> bytes:
        """
        Returns a :class:`bytes` body representing the data in this object.

        :return: A :class:`bytes` body representing the data in this object.
        :rtype: bytes
        """
        body_json = self.to_json()
        return bytes(body_json, 'utf-8')

    def to_message(self, request_message: Optional[GenericMessage] = None) -> GenericMessage:
        """
        Returns a :class:`systemlink.messagebus.generic_message.GenericMessage`
        object representing the data in this object.

        :param request_message: Request message if this is a response.
        :type request_message: Optional[GenericMessage]
        :return: A :class:`systemlink.messagebus.generic_message.GenericMessage`
            object representing the data in this object.
        :rtype: GenericMessage
        """
        header = self.header
        if request_message:
            request_header = request_message.header
            header.correlation_id = request_header.correlation_id
        body_bytes = self.to_body_bytes()
        return GenericMessage(header, body_bytes)

    @property
    def body_bytes(self) -> bytes:
        """
        Returns a :class:`bytes` body representing the data in this object.

        :return: A :class:`bytes` body representing the data in this object.
        :rtype: bytes
        """
        self._body = self.to_body_bytes()  # pylint: disable=attribute-defined-outside-init
        return self._body

    @body_bytes.setter
    def body_bytes(self, body_bytes: Optional[bytes]) -> None:  # pylint: disable=no-self-use,unused-argument
        """
        Set the raw message body.

        Not implemented. Do not use!

        :param body_bytes: The raw message body.
        :type body_bytes: Optional[bytes]
        """
        # This class method is defined simply because it is defined in
        # the base class.
        raise NotImplementedError("ConfigurationGetValueRequest does not support setting 'body_bytes'")


class ConfigurationGetValueResponse(ResponseMessage):
    """
    ConfigurationGetValueResponse JSON response message.
    """
    MESSAGE_NAME = 'ConfigurationGetValueResponse'

    def __init__(
            self,
            request_message: Optional[Union[GenericMessage, MessageBase]],
            value_=None
        ) -> None:
        """
        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: Optional[Union[GenericMessage, MessageBase]]
        :param value_: value
        :type value_: str
        """
        self.value = value_
        header = MessageHeader()
        header.message_name = self.MESSAGE_NAME
        header.content_type = JSON_MESSAGE_CONTENT_TYPE
        # If request_message is None, routing key needs to be set outside this constructor.
        if request_message:
            header.correlation_id = request_message.correlation_id
            routing_key = MessageHeader.generate_routing_key(request_message.reply_to, self.MESSAGE_NAME)
            header.routing_key = routing_key
        super().__init__(header, None)

    @classmethod
    def from_dict(
            cls,
            request_message: Optional[Union[GenericMessage, MessageBase]],
            body_dict: Dict[str, Any]
        ) -> 'ConfigurationGetValueResponse':
        """
        Create a new instance of :class:`ConfigurationGetValueResponse` using a dictionary.

        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: Optional[Union[GenericMessage, MessageBase]]
        :param body_dict: The body as a dictionary.
        :type body_dict: Dict[str, Any]
        :return: A new instance of :class:`ConfigurationGetValueResponse`.
        :rtype: ConfigurationGetValueResponse
        """
        value_ = _deserialize(body_dict.get('value'), 'str')
        return cls(
            request_message,
            value_=value_
        )

    @classmethod
    def from_json(
            cls,
            request_message: Optional[Union[GenericMessage, MessageBase]],
            body_json: str
        ) -> 'ConfigurationGetValueResponse':
        """
        Create a new instance of :class:`ConfigurationGetValueResponse` using a JSON string.

        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: Optional[Union[GenericMessage, MessageBase]]
        :param body_json: A string in JSON format representing the body.
        :type body_json: str
        :return: A new instance of :class:`ConfigurationGetValueResponse`.
        :rtype: ConfigurationGetValueResponse
        """
        body_dict = cast(Dict[str, Any], json.loads(body_json))
        return cls.from_dict(request_message, body_dict)

    @classmethod
    def from_body_bytes(
            cls,
            request_message: Optional[Union[GenericMessage, MessageBase]],
            body_bytes: Union[bytes, bytearray]
        ) -> 'ConfigurationGetValueResponse':
        """
        Create a new instance of :class:`ConfigurationGetValueResponse` using a body
        of type :class:`bytes` or :class:`bytearray`,

        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: Optional[Union[GenericMessage, MessageBase]]
        :param body_bytes: The body to use.
        :type body_bytes: Union[bytes, bytearray]
        :return: A new instance of :class:`ConfigurationGetValueResponse`.
        :rtype: ConfigurationGetValueResponse
        """
        body_json = str(body_bytes, 'utf-8')
        return cls.from_json(request_message, body_json)

    @classmethod
    def from_message(cls, message: GenericMessage) -> 'ConfigurationGetValueResponse':
        """
        Create a new instance of :class`ConfigurationGetValueResponse` using a
        :class:`systemlink.messagebus.message_base.MessageBase` derived message.

        :param message: The message to use as the basis for this class instance.
        :type message: GenericMessage
        :return: A new instance of :class`ConfigurationGetValueResponse`.
        :rtype: ConfigurationGetValueResponse
        """
        instance = cls.from_body_bytes(message, message.body_bytes)
        instance.correlation_id = message.correlation_id
        instance.reply_to = message.reply_to
        routing_key = MessageHeader.generate_routing_key(message.reply_to, cls.MESSAGE_NAME)
        instance.routing_key = routing_key
        return instance

    def to_dict(self) -> Dict[str, Any]:
        """
        Returns a dictionary representing the data in this object.

        :return: A dictionary representing the data in this object.
        :rtype: Dict[str, Any]
        """
        value_ = _serialize(self.value)
        return {
            'value': value_
        }

    def to_json(self) -> str:
        """
        Returns a JSON string representing the data in this object.

        :return: A JSON string representing the data in this object.
        :rtype: str
        """
        body_dict = self.to_dict()
        return json.dumps(body_dict, separators=(',', ':'))

    def to_body_bytes(self) -> bytes:
        """
        Returns a :class:`bytes` body representing the data in this object.

        :return: A :class:`bytes` body representing the data in this object.
        :rtype: bytes
        """
        body_json = self.to_json()
        return bytes(body_json, 'utf-8')

    def to_message(self, request_message: Optional[GenericMessage] = None) -> GenericMessage:
        """
        Returns a :class:`systemlink.messagebus.generic_message.GenericMessage`
        object representing the data in this object.

        :param request_message: Request message if this is a response.
        :type request_message: Optional[GenericMessage]
        :return: A :class:`systemlink.messagebus.generic_message.GenericMessage`
            object representing the data in this object.
        :rtype: GenericMessage
        """
        header = self.header
        if request_message:
            request_header = request_message.header
            header.correlation_id = request_header.correlation_id
            routing_key = MessageHeader.generate_routing_key(request_header.reply_to, self.MESSAGE_NAME)
            header.routing_key = routing_key
        body_bytes = self.to_body_bytes()
        return GenericMessage(header, body_bytes)

    @property
    def body_bytes(self) -> bytes:
        """
        Returns a :class:`bytes` body representing the data in this object.

        :return: A :class:`bytes` body representing the data in this object.
        :rtype: bytes
        """
        self._body = self.to_body_bytes()  # pylint: disable=attribute-defined-outside-init
        return self._body

    @body_bytes.setter
    def body_bytes(self, body_bytes: Optional[bytes]) -> None:  # pylint: disable=no-self-use,unused-argument
        """
        Set the raw message body.

        Not implemented. Do not use!

        :param body_bytes: The raw message body.
        :type body_bytes: Optional[bytes]
        """
        # This class method is defined simply because it is defined in
        # the base class.
        raise NotImplementedError("ConfigurationGetValueResponse does not support setting 'body_bytes'")


class ConfigurationSetValueRequest(RequestMessage):
    """
    ConfigurationSetValueRequest JSON request message.
    """
    MESSAGE_NAME = 'ConfigurationSetValueRequest'

    def __init__(
            self,
            user_=None,
            section_=None,
            key_=None,
            value_=None
        ) -> None:
        """
        :param user_: user
        :type user_: str
        :param section_: section
        :type section_: str
        :param key_: key
        :type key_: str
        :param value_: value
        :type value_: str
        """
        self.user = user_
        self.section = section_
        self.key = key_
        self.value = value_
        header = MessageHeader()
        header.message_name = self.MESSAGE_NAME
        header.content_type = JSON_MESSAGE_CONTENT_TYPE
        routing_key = MessageHeader.generate_routing_key('Configuration', self.MESSAGE_NAME)
        header.routing_key = routing_key
        super().__init__(header, None)

    @classmethod
    def from_dict(cls, body_dict: Dict[str, Any]) -> 'ConfigurationSetValueRequest':
        """
        Create a new instance of :class:`ConfigurationSetValueRequest` using a dictionary.

        :param body_dict: The body as a dictionary.
        :type body_dict: Dict[str, Any]
        :return: A new instance of :class:`ConfigurationSetValueRequest`.
        :rtype: ConfigurationSetValueRequest
        """
        user_ = _deserialize(body_dict.get('user'), 'str')
        section_ = _deserialize(body_dict.get('section'), 'str')
        key_ = _deserialize(body_dict.get('key'), 'str')
        value_ = _deserialize(body_dict.get('value'), 'str')
        return cls(
            user_=user_,
            section_=section_,
            key_=key_,
            value_=value_
        )

    @classmethod
    def from_json(cls, body_json: str) -> 'ConfigurationSetValueRequest':
        """
        Create a new instance of :class:`ConfigurationSetValueRequest` using a JSON string.

        :param body_json: A string in JSON format representing the body.
        :type body_json: str
        :return: A new instance of :class:`ConfigurationSetValueRequest`.
        :rtype: ConfigurationSetValueRequest
        """
        body_dict = cast(Dict[str, Any], json.loads(body_json))
        return cls.from_dict(body_dict)

    @classmethod
    def from_body_bytes(cls, body_bytes: Union[bytes, bytearray]) -> 'ConfigurationSetValueRequest':
        """
        Create a new instance of :class:`ConfigurationSetValueRequest` using a body
        of type :class:`bytes` or :class:`bytearray`,

        :param body_bytes: The body to use.
        :type body_bytes: Union[bytes, bytearray]
        :return: A new instance of :class:`ConfigurationSetValueRequest`.
        :rtype: ConfigurationSetValueRequest
        """
        body_json = str(body_bytes, 'utf-8')
        return cls.from_json(body_json)

    @classmethod
    def from_message(cls, message: GenericMessage) -> 'ConfigurationSetValueRequest':
        """
        Create a new instance of :class`ConfigurationSetValueRequest` using a
        :class:`systemlink.messagebus.message_base.MessageBase` derived message.

        :param message: The message to use as the basis for this class instance.
        :type message: GenericMessage
        :return: A new instance of :class`ConfigurationSetValueRequest`.
        :rtype: ConfigurationSetValueRequest
        """
        instance = cls.from_body_bytes(message.body_bytes)
        instance.correlation_id = message.correlation_id
        instance.reply_to = message.reply_to
        return instance

    def to_dict(self) -> Dict[str, Any]:
        """
        Returns a dictionary representing the data in this object.

        :return: A dictionary representing the data in this object.
        :rtype: Dict[str, Any]
        """
        user_ = _serialize(self.user)
        section_ = _serialize(self.section)
        key_ = _serialize(self.key)
        value_ = _serialize(self.value)
        return {
            'user': user_,
            'section': section_,
            'key': key_,
            'value': value_
        }

    def to_json(self) -> str:
        """
        Returns a JSON string representing the data in this object.

        :return: A JSON string representing the data in this object.
        :rtype: str
        """
        body_dict = self.to_dict()
        return json.dumps(body_dict, separators=(',', ':'))

    def to_body_bytes(self) -> bytes:
        """
        Returns a :class:`bytes` body representing the data in this object.

        :return: A :class:`bytes` body representing the data in this object.
        :rtype: bytes
        """
        body_json = self.to_json()
        return bytes(body_json, 'utf-8')

    def to_message(self, request_message: Optional[GenericMessage] = None) -> GenericMessage:
        """
        Returns a :class:`systemlink.messagebus.generic_message.GenericMessage`
        object representing the data in this object.

        :param request_message: Request message if this is a response.
        :type request_message: Optional[GenericMessage]
        :return: A :class:`systemlink.messagebus.generic_message.GenericMessage`
            object representing the data in this object.
        :rtype: GenericMessage
        """
        header = self.header
        if request_message:
            request_header = request_message.header
            header.correlation_id = request_header.correlation_id
        body_bytes = self.to_body_bytes()
        return GenericMessage(header, body_bytes)

    @property
    def body_bytes(self) -> bytes:
        """
        Returns a :class:`bytes` body representing the data in this object.

        :return: A :class:`bytes` body representing the data in this object.
        :rtype: bytes
        """
        self._body = self.to_body_bytes()  # pylint: disable=attribute-defined-outside-init
        return self._body

    @body_bytes.setter
    def body_bytes(self, body_bytes: Optional[bytes]) -> None:  # pylint: disable=no-self-use,unused-argument
        """
        Set the raw message body.

        Not implemented. Do not use!

        :param body_bytes: The raw message body.
        :type body_bytes: Optional[bytes]
        """
        # This class method is defined simply because it is defined in
        # the base class.
        raise NotImplementedError("ConfigurationSetValueRequest does not support setting 'body_bytes'")


class ConfigurationSetValueResponse(ResponseMessage):
    """
    ConfigurationSetValueResponse JSON response message.
    """
    MESSAGE_NAME = 'ConfigurationSetValueResponse'

    def __init__(
            self,
            request_message: Optional[Union[GenericMessage, MessageBase]]
        ) -> None:
        header = MessageHeader()
        header.message_name = self.MESSAGE_NAME
        header.content_type = JSON_MESSAGE_CONTENT_TYPE
        # If request_message is None, routing key needs to be set outside this constructor.
        if request_message:
            header.correlation_id = request_message.correlation_id
            routing_key = MessageHeader.generate_routing_key(request_message.reply_to, self.MESSAGE_NAME)
            header.routing_key = routing_key
        super().__init__(header, None)

    @classmethod
    def from_dict(  # pylint: disable=unused-argument
            cls,
            request_message: Optional[Union[GenericMessage, MessageBase]],
            body_dict: Dict[str, Any]
        ) -> 'ConfigurationSetValueResponse':
        """
        Create a new instance of :class:`ConfigurationSetValueResponse` using a dictionary.

        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: Optional[Union[GenericMessage, MessageBase]]
        :param body_dict: The body as a dictionary.
        :type body_dict: Dict[str, Any]
        :return: A new instance of :class:`ConfigurationSetValueResponse`.
        :rtype: ConfigurationSetValueResponse
        """
        return cls(
            request_message
        )

    @classmethod
    def from_json(
            cls,
            request_message: Optional[Union[GenericMessage, MessageBase]],
            body_json: str
        ) -> 'ConfigurationSetValueResponse':
        """
        Create a new instance of :class:`ConfigurationSetValueResponse` using a JSON string.

        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: Optional[Union[GenericMessage, MessageBase]]
        :param body_json: A string in JSON format representing the body.
        :type body_json: str
        :return: A new instance of :class:`ConfigurationSetValueResponse`.
        :rtype: ConfigurationSetValueResponse
        """
        body_dict = cast(Dict[str, Any], json.loads(body_json))
        return cls.from_dict(request_message, body_dict)

    @classmethod
    def from_body_bytes(
            cls,
            request_message: Optional[Union[GenericMessage, MessageBase]],
            body_bytes: Union[bytes, bytearray]
        ) -> 'ConfigurationSetValueResponse':
        """
        Create a new instance of :class:`ConfigurationSetValueResponse` using a body
        of type :class:`bytes` or :class:`bytearray`,

        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: Optional[Union[GenericMessage, MessageBase]]
        :param body_bytes: The body to use.
        :type body_bytes: Union[bytes, bytearray]
        :return: A new instance of :class:`ConfigurationSetValueResponse`.
        :rtype: ConfigurationSetValueResponse
        """
        body_json = str(body_bytes, 'utf-8')
        return cls.from_json(request_message, body_json)

    @classmethod
    def from_message(cls, message: GenericMessage) -> 'ConfigurationSetValueResponse':
        """
        Create a new instance of :class`ConfigurationSetValueResponse` using a
        :class:`systemlink.messagebus.message_base.MessageBase` derived message.

        :param message: The message to use as the basis for this class instance.
        :type message: GenericMessage
        :return: A new instance of :class`ConfigurationSetValueResponse`.
        :rtype: ConfigurationSetValueResponse
        """
        instance = cls.from_body_bytes(message, message.body_bytes)
        instance.correlation_id = message.correlation_id
        instance.reply_to = message.reply_to
        routing_key = MessageHeader.generate_routing_key(message.reply_to, cls.MESSAGE_NAME)
        instance.routing_key = routing_key
        return instance

    def to_dict(self) -> Dict[str, Any]:  # pylint: disable=no-self-use
        """
        Returns a dictionary representing the data in this object.

        :return: A dictionary representing the data in this object.
        :rtype: Dict[str, Any]
        """
        return {
        }

    def to_json(self) -> str:
        """
        Returns a JSON string representing the data in this object.

        :return: A JSON string representing the data in this object.
        :rtype: str
        """
        body_dict = self.to_dict()
        return json.dumps(body_dict, separators=(',', ':'))

    def to_body_bytes(self) -> bytes:
        """
        Returns a :class:`bytes` body representing the data in this object.

        :return: A :class:`bytes` body representing the data in this object.
        :rtype: bytes
        """
        body_json = self.to_json()
        return bytes(body_json, 'utf-8')

    def to_message(self, request_message: Optional[GenericMessage] = None) -> GenericMessage:
        """
        Returns a :class:`systemlink.messagebus.generic_message.GenericMessage`
        object representing the data in this object.

        :param request_message: Request message if this is a response.
        :type request_message: Optional[GenericMessage]
        :return: A :class:`systemlink.messagebus.generic_message.GenericMessage`
            object representing the data in this object.
        :rtype: GenericMessage
        """
        header = self.header
        if request_message:
            request_header = request_message.header
            header.correlation_id = request_header.correlation_id
            routing_key = MessageHeader.generate_routing_key(request_header.reply_to, self.MESSAGE_NAME)
            header.routing_key = routing_key
        body_bytes = self.to_body_bytes()
        return GenericMessage(header, body_bytes)

    @property
    def body_bytes(self) -> bytes:
        """
        Returns a :class:`bytes` body representing the data in this object.

        :return: A :class:`bytes` body representing the data in this object.
        :rtype: bytes
        """
        self._body = self.to_body_bytes()  # pylint: disable=attribute-defined-outside-init
        return self._body

    @body_bytes.setter
    def body_bytes(self, body_bytes: Optional[bytes]) -> None:  # pylint: disable=no-self-use,unused-argument
        """
        Set the raw message body.

        Not implemented. Do not use!

        :param body_bytes: The raw message body.
        :type body_bytes: Optional[bytes]
        """
        # This class method is defined simply because it is defined in
        # the base class.
        raise NotImplementedError("ConfigurationSetValueResponse does not support setting 'body_bytes'")


class ConfigurationGetSectionsRequest(RequestMessage):
    """
    ConfigurationGetSectionsRequest JSON request message.
    """
    MESSAGE_NAME = 'ConfigurationGetSectionsRequest'

    def __init__(
            self
        ) -> None:
        header = MessageHeader()
        header.message_name = self.MESSAGE_NAME
        header.content_type = JSON_MESSAGE_CONTENT_TYPE
        routing_key = MessageHeader.generate_routing_key('Configuration', self.MESSAGE_NAME)
        header.routing_key = routing_key
        super().__init__(header, None)

    @classmethod
    def from_dict(cls, body_dict: Dict[str, Any]) -> 'ConfigurationGetSectionsRequest':  # pylint: disable=unused-argument
        """
        Create a new instance of :class:`ConfigurationGetSectionsRequest` using a dictionary.

        :param body_dict: The body as a dictionary.
        :type body_dict: Dict[str, Any]
        :return: A new instance of :class:`ConfigurationGetSectionsRequest`.
        :rtype: ConfigurationGetSectionsRequest
        """
        return cls(
        )

    @classmethod
    def from_json(cls, body_json: str) -> 'ConfigurationGetSectionsRequest':
        """
        Create a new instance of :class:`ConfigurationGetSectionsRequest` using a JSON string.

        :param body_json: A string in JSON format representing the body.
        :type body_json: str
        :return: A new instance of :class:`ConfigurationGetSectionsRequest`.
        :rtype: ConfigurationGetSectionsRequest
        """
        body_dict = cast(Dict[str, Any], json.loads(body_json))
        return cls.from_dict(body_dict)

    @classmethod
    def from_body_bytes(cls, body_bytes: Union[bytes, bytearray]) -> 'ConfigurationGetSectionsRequest':
        """
        Create a new instance of :class:`ConfigurationGetSectionsRequest` using a body
        of type :class:`bytes` or :class:`bytearray`,

        :param body_bytes: The body to use.
        :type body_bytes: Union[bytes, bytearray]
        :return: A new instance of :class:`ConfigurationGetSectionsRequest`.
        :rtype: ConfigurationGetSectionsRequest
        """
        body_json = str(body_bytes, 'utf-8')
        return cls.from_json(body_json)

    @classmethod
    def from_message(cls, message: GenericMessage) -> 'ConfigurationGetSectionsRequest':
        """
        Create a new instance of :class`ConfigurationGetSectionsRequest` using a
        :class:`systemlink.messagebus.message_base.MessageBase` derived message.

        :param message: The message to use as the basis for this class instance.
        :type message: GenericMessage
        :return: A new instance of :class`ConfigurationGetSectionsRequest`.
        :rtype: ConfigurationGetSectionsRequest
        """
        instance = cls.from_body_bytes(message.body_bytes)
        instance.correlation_id = message.correlation_id
        instance.reply_to = message.reply_to
        return instance

    def to_dict(self) -> Dict[str, Any]:  # pylint: disable=no-self-use
        """
        Returns a dictionary representing the data in this object.

        :return: A dictionary representing the data in this object.
        :rtype: Dict[str, Any]
        """
        return {
        }

    def to_json(self) -> str:
        """
        Returns a JSON string representing the data in this object.

        :return: A JSON string representing the data in this object.
        :rtype: str
        """
        body_dict = self.to_dict()
        return json.dumps(body_dict, separators=(',', ':'))

    def to_body_bytes(self) -> bytes:
        """
        Returns a :class:`bytes` body representing the data in this object.

        :return: A :class:`bytes` body representing the data in this object.
        :rtype: bytes
        """
        body_json = self.to_json()
        return bytes(body_json, 'utf-8')

    def to_message(self, request_message: Optional[GenericMessage] = None) -> GenericMessage:
        """
        Returns a :class:`systemlink.messagebus.generic_message.GenericMessage`
        object representing the data in this object.

        :param request_message: Request message if this is a response.
        :type request_message: Optional[GenericMessage]
        :return: A :class:`systemlink.messagebus.generic_message.GenericMessage`
            object representing the data in this object.
        :rtype: GenericMessage
        """
        header = self.header
        if request_message:
            request_header = request_message.header
            header.correlation_id = request_header.correlation_id
        body_bytes = self.to_body_bytes()
        return GenericMessage(header, body_bytes)

    @property
    def body_bytes(self) -> bytes:
        """
        Returns a :class:`bytes` body representing the data in this object.

        :return: A :class:`bytes` body representing the data in this object.
        :rtype: bytes
        """
        self._body = self.to_body_bytes()  # pylint: disable=attribute-defined-outside-init
        return self._body

    @body_bytes.setter
    def body_bytes(self, body_bytes: Optional[bytes]) -> None:  # pylint: disable=no-self-use,unused-argument
        """
        Set the raw message body.

        Not implemented. Do not use!

        :param body_bytes: The raw message body.
        :type body_bytes: Optional[bytes]
        """
        # This class method is defined simply because it is defined in
        # the base class.
        raise NotImplementedError("ConfigurationGetSectionsRequest does not support setting 'body_bytes'")


class ConfigurationGetSectionsResponse(ResponseMessage):
    """
    ConfigurationGetSectionsResponse JSON response message.
    """
    MESSAGE_NAME = 'ConfigurationGetSectionsResponse'

    def __init__(
            self,
            request_message: Optional[Union[GenericMessage, MessageBase]],
            sections_=None
        ) -> None:
        """
        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: Optional[Union[GenericMessage, MessageBase]]
        :param sections_: sections
        :type sections_: List[str]
        """
        self.sections = sections_
        header = MessageHeader()
        header.message_name = self.MESSAGE_NAME
        header.content_type = JSON_MESSAGE_CONTENT_TYPE
        # If request_message is None, routing key needs to be set outside this constructor.
        if request_message:
            header.correlation_id = request_message.correlation_id
            routing_key = MessageHeader.generate_routing_key(request_message.reply_to, self.MESSAGE_NAME)
            header.routing_key = routing_key
        super().__init__(header, None)

    @classmethod
    def from_dict(
            cls,
            request_message: Optional[Union[GenericMessage, MessageBase]],
            body_dict: Dict[str, Any]
        ) -> 'ConfigurationGetSectionsResponse':
        """
        Create a new instance of :class:`ConfigurationGetSectionsResponse` using a dictionary.

        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: Optional[Union[GenericMessage, MessageBase]]
        :param body_dict: The body as a dictionary.
        :type body_dict: Dict[str, Any]
        :return: A new instance of :class:`ConfigurationGetSectionsResponse`.
        :rtype: ConfigurationGetSectionsResponse
        """
        sections_ = _deserialize(body_dict.get('sections'), 'List[str]')
        return cls(
            request_message,
            sections_=sections_
        )

    @classmethod
    def from_json(
            cls,
            request_message: Optional[Union[GenericMessage, MessageBase]],
            body_json: str
        ) -> 'ConfigurationGetSectionsResponse':
        """
        Create a new instance of :class:`ConfigurationGetSectionsResponse` using a JSON string.

        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: Optional[Union[GenericMessage, MessageBase]]
        :param body_json: A string in JSON format representing the body.
        :type body_json: str
        :return: A new instance of :class:`ConfigurationGetSectionsResponse`.
        :rtype: ConfigurationGetSectionsResponse
        """
        body_dict = cast(Dict[str, Any], json.loads(body_json))
        return cls.from_dict(request_message, body_dict)

    @classmethod
    def from_body_bytes(
            cls,
            request_message: Optional[Union[GenericMessage, MessageBase]],
            body_bytes: Union[bytes, bytearray]
        ) -> 'ConfigurationGetSectionsResponse':
        """
        Create a new instance of :class:`ConfigurationGetSectionsResponse` using a body
        of type :class:`bytes` or :class:`bytearray`,

        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: Optional[Union[GenericMessage, MessageBase]]
        :param body_bytes: The body to use.
        :type body_bytes: Union[bytes, bytearray]
        :return: A new instance of :class:`ConfigurationGetSectionsResponse`.
        :rtype: ConfigurationGetSectionsResponse
        """
        body_json = str(body_bytes, 'utf-8')
        return cls.from_json(request_message, body_json)

    @classmethod
    def from_message(cls, message: GenericMessage) -> 'ConfigurationGetSectionsResponse':
        """
        Create a new instance of :class`ConfigurationGetSectionsResponse` using a
        :class:`systemlink.messagebus.message_base.MessageBase` derived message.

        :param message: The message to use as the basis for this class instance.
        :type message: GenericMessage
        :return: A new instance of :class`ConfigurationGetSectionsResponse`.
        :rtype: ConfigurationGetSectionsResponse
        """
        instance = cls.from_body_bytes(message, message.body_bytes)
        instance.correlation_id = message.correlation_id
        instance.reply_to = message.reply_to
        routing_key = MessageHeader.generate_routing_key(message.reply_to, cls.MESSAGE_NAME)
        instance.routing_key = routing_key
        return instance

    def to_dict(self) -> Dict[str, Any]:
        """
        Returns a dictionary representing the data in this object.

        :return: A dictionary representing the data in this object.
        :rtype: Dict[str, Any]
        """
        sections_ = _serialize(self.sections)
        return {
            'sections': sections_
        }

    def to_json(self) -> str:
        """
        Returns a JSON string representing the data in this object.

        :return: A JSON string representing the data in this object.
        :rtype: str
        """
        body_dict = self.to_dict()
        return json.dumps(body_dict, separators=(',', ':'))

    def to_body_bytes(self) -> bytes:
        """
        Returns a :class:`bytes` body representing the data in this object.

        :return: A :class:`bytes` body representing the data in this object.
        :rtype: bytes
        """
        body_json = self.to_json()
        return bytes(body_json, 'utf-8')

    def to_message(self, request_message: Optional[GenericMessage] = None) -> GenericMessage:
        """
        Returns a :class:`systemlink.messagebus.generic_message.GenericMessage`
        object representing the data in this object.

        :param request_message: Request message if this is a response.
        :type request_message: Optional[GenericMessage]
        :return: A :class:`systemlink.messagebus.generic_message.GenericMessage`
            object representing the data in this object.
        :rtype: GenericMessage
        """
        header = self.header
        if request_message:
            request_header = request_message.header
            header.correlation_id = request_header.correlation_id
            routing_key = MessageHeader.generate_routing_key(request_header.reply_to, self.MESSAGE_NAME)
            header.routing_key = routing_key
        body_bytes = self.to_body_bytes()
        return GenericMessage(header, body_bytes)

    @property
    def body_bytes(self) -> bytes:
        """
        Returns a :class:`bytes` body representing the data in this object.

        :return: A :class:`bytes` body representing the data in this object.
        :rtype: bytes
        """
        self._body = self.to_body_bytes()  # pylint: disable=attribute-defined-outside-init
        return self._body

    @body_bytes.setter
    def body_bytes(self, body_bytes: Optional[bytes]) -> None:  # pylint: disable=no-self-use,unused-argument
        """
        Set the raw message body.

        Not implemented. Do not use!

        :param body_bytes: The raw message body.
        :type body_bytes: Optional[bytes]
        """
        # This class method is defined simply because it is defined in
        # the base class.
        raise NotImplementedError("ConfigurationGetSectionsResponse does not support setting 'body_bytes'")


class ConfigurationGetSectionKeyValuesRequest(RequestMessage):
    """
    ConfigurationGetSectionKeyValuesRequest JSON request message.
    """
    MESSAGE_NAME = 'ConfigurationGetSectionKeyValuesRequest'

    def __init__(
            self,
            sections_=None
        ) -> None:
        """
        :param sections_: sections
        :type sections_: List[str]
        """
        self.sections = sections_
        header = MessageHeader()
        header.message_name = self.MESSAGE_NAME
        header.content_type = JSON_MESSAGE_CONTENT_TYPE
        routing_key = MessageHeader.generate_routing_key('Configuration', self.MESSAGE_NAME)
        header.routing_key = routing_key
        super().__init__(header, None)

    @classmethod
    def from_dict(cls, body_dict: Dict[str, Any]) -> 'ConfigurationGetSectionKeyValuesRequest':
        """
        Create a new instance of :class:`ConfigurationGetSectionKeyValuesRequest` using a dictionary.

        :param body_dict: The body as a dictionary.
        :type body_dict: Dict[str, Any]
        :return: A new instance of :class:`ConfigurationGetSectionKeyValuesRequest`.
        :rtype: ConfigurationGetSectionKeyValuesRequest
        """
        sections_ = _deserialize(body_dict.get('sections'), 'List[str]')
        return cls(
            sections_=sections_
        )

    @classmethod
    def from_json(cls, body_json: str) -> 'ConfigurationGetSectionKeyValuesRequest':
        """
        Create a new instance of :class:`ConfigurationGetSectionKeyValuesRequest` using a JSON string.

        :param body_json: A string in JSON format representing the body.
        :type body_json: str
        :return: A new instance of :class:`ConfigurationGetSectionKeyValuesRequest`.
        :rtype: ConfigurationGetSectionKeyValuesRequest
        """
        body_dict = cast(Dict[str, Any], json.loads(body_json))
        return cls.from_dict(body_dict)

    @classmethod
    def from_body_bytes(cls, body_bytes: Union[bytes, bytearray]) -> 'ConfigurationGetSectionKeyValuesRequest':
        """
        Create a new instance of :class:`ConfigurationGetSectionKeyValuesRequest` using a body
        of type :class:`bytes` or :class:`bytearray`,

        :param body_bytes: The body to use.
        :type body_bytes: Union[bytes, bytearray]
        :return: A new instance of :class:`ConfigurationGetSectionKeyValuesRequest`.
        :rtype: ConfigurationGetSectionKeyValuesRequest
        """
        body_json = str(body_bytes, 'utf-8')
        return cls.from_json(body_json)

    @classmethod
    def from_message(cls, message: GenericMessage) -> 'ConfigurationGetSectionKeyValuesRequest':
        """
        Create a new instance of :class`ConfigurationGetSectionKeyValuesRequest` using a
        :class:`systemlink.messagebus.message_base.MessageBase` derived message.

        :param message: The message to use as the basis for this class instance.
        :type message: GenericMessage
        :return: A new instance of :class`ConfigurationGetSectionKeyValuesRequest`.
        :rtype: ConfigurationGetSectionKeyValuesRequest
        """
        instance = cls.from_body_bytes(message.body_bytes)
        instance.correlation_id = message.correlation_id
        instance.reply_to = message.reply_to
        return instance

    def to_dict(self) -> Dict[str, Any]:
        """
        Returns a dictionary representing the data in this object.

        :return: A dictionary representing the data in this object.
        :rtype: Dict[str, Any]
        """
        sections_ = _serialize(self.sections)
        return {
            'sections': sections_
        }

    def to_json(self) -> str:
        """
        Returns a JSON string representing the data in this object.

        :return: A JSON string representing the data in this object.
        :rtype: str
        """
        body_dict = self.to_dict()
        return json.dumps(body_dict, separators=(',', ':'))

    def to_body_bytes(self) -> bytes:
        """
        Returns a :class:`bytes` body representing the data in this object.

        :return: A :class:`bytes` body representing the data in this object.
        :rtype: bytes
        """
        body_json = self.to_json()
        return bytes(body_json, 'utf-8')

    def to_message(self, request_message: Optional[GenericMessage] = None) -> GenericMessage:
        """
        Returns a :class:`systemlink.messagebus.generic_message.GenericMessage`
        object representing the data in this object.

        :param request_message: Request message if this is a response.
        :type request_message: Optional[GenericMessage]
        :return: A :class:`systemlink.messagebus.generic_message.GenericMessage`
            object representing the data in this object.
        :rtype: GenericMessage
        """
        header = self.header
        if request_message:
            request_header = request_message.header
            header.correlation_id = request_header.correlation_id
        body_bytes = self.to_body_bytes()
        return GenericMessage(header, body_bytes)

    @property
    def body_bytes(self) -> bytes:
        """
        Returns a :class:`bytes` body representing the data in this object.

        :return: A :class:`bytes` body representing the data in this object.
        :rtype: bytes
        """
        self._body = self.to_body_bytes()  # pylint: disable=attribute-defined-outside-init
        return self._body

    @body_bytes.setter
    def body_bytes(self, body_bytes: Optional[bytes]) -> None:  # pylint: disable=no-self-use,unused-argument
        """
        Set the raw message body.

        Not implemented. Do not use!

        :param body_bytes: The raw message body.
        :type body_bytes: Optional[bytes]
        """
        # This class method is defined simply because it is defined in
        # the base class.
        raise NotImplementedError("ConfigurationGetSectionKeyValuesRequest does not support setting 'body_bytes'")


class ConfigurationGetSectionKeyValuesResponse(ResponseMessage):
    """
    ConfigurationGetSectionKeyValuesResponse JSON response message.
    """
    MESSAGE_NAME = 'ConfigurationGetSectionKeyValuesResponse'

    def __init__(
            self,
            request_message: Optional[Union[GenericMessage, MessageBase]],
            key_values_=None
        ) -> None:
        """
        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: Optional[Union[GenericMessage, MessageBase]]
        :param key_values_: key_values
        :type key_values_: List[SectionKeyValues]
        """
        self.key_values = key_values_
        header = MessageHeader()
        header.message_name = self.MESSAGE_NAME
        header.content_type = JSON_MESSAGE_CONTENT_TYPE
        # If request_message is None, routing key needs to be set outside this constructor.
        if request_message:
            header.correlation_id = request_message.correlation_id
            routing_key = MessageHeader.generate_routing_key(request_message.reply_to, self.MESSAGE_NAME)
            header.routing_key = routing_key
        super().__init__(header, None)

    @classmethod
    def from_dict(
            cls,
            request_message: Optional[Union[GenericMessage, MessageBase]],
            body_dict: Dict[str, Any]
        ) -> 'ConfigurationGetSectionKeyValuesResponse':
        """
        Create a new instance of :class:`ConfigurationGetSectionKeyValuesResponse` using a dictionary.

        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: Optional[Union[GenericMessage, MessageBase]]
        :param body_dict: The body as a dictionary.
        :type body_dict: Dict[str, Any]
        :return: A new instance of :class:`ConfigurationGetSectionKeyValuesResponse`.
        :rtype: ConfigurationGetSectionKeyValuesResponse
        """
        key_values_ = _deserialize(body_dict.get('keyValues'), 'List[SectionKeyValues]')
        return cls(
            request_message,
            key_values_=key_values_
        )

    @classmethod
    def from_json(
            cls,
            request_message: Optional[Union[GenericMessage, MessageBase]],
            body_json: str
        ) -> 'ConfigurationGetSectionKeyValuesResponse':
        """
        Create a new instance of :class:`ConfigurationGetSectionKeyValuesResponse` using a JSON string.

        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: Optional[Union[GenericMessage, MessageBase]]
        :param body_json: A string in JSON format representing the body.
        :type body_json: str
        :return: A new instance of :class:`ConfigurationGetSectionKeyValuesResponse`.
        :rtype: ConfigurationGetSectionKeyValuesResponse
        """
        body_dict = cast(Dict[str, Any], json.loads(body_json))
        return cls.from_dict(request_message, body_dict)

    @classmethod
    def from_body_bytes(
            cls,
            request_message: Optional[Union[GenericMessage, MessageBase]],
            body_bytes: Union[bytes, bytearray]
        ) -> 'ConfigurationGetSectionKeyValuesResponse':
        """
        Create a new instance of :class:`ConfigurationGetSectionKeyValuesResponse` using a body
        of type :class:`bytes` or :class:`bytearray`,

        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: Optional[Union[GenericMessage, MessageBase]]
        :param body_bytes: The body to use.
        :type body_bytes: Union[bytes, bytearray]
        :return: A new instance of :class:`ConfigurationGetSectionKeyValuesResponse`.
        :rtype: ConfigurationGetSectionKeyValuesResponse
        """
        body_json = str(body_bytes, 'utf-8')
        return cls.from_json(request_message, body_json)

    @classmethod
    def from_message(cls, message: GenericMessage) -> 'ConfigurationGetSectionKeyValuesResponse':
        """
        Create a new instance of :class`ConfigurationGetSectionKeyValuesResponse` using a
        :class:`systemlink.messagebus.message_base.MessageBase` derived message.

        :param message: The message to use as the basis for this class instance.
        :type message: GenericMessage
        :return: A new instance of :class`ConfigurationGetSectionKeyValuesResponse`.
        :rtype: ConfigurationGetSectionKeyValuesResponse
        """
        instance = cls.from_body_bytes(message, message.body_bytes)
        instance.correlation_id = message.correlation_id
        instance.reply_to = message.reply_to
        routing_key = MessageHeader.generate_routing_key(message.reply_to, cls.MESSAGE_NAME)
        instance.routing_key = routing_key
        return instance

    def to_dict(self) -> Dict[str, Any]:
        """
        Returns a dictionary representing the data in this object.

        :return: A dictionary representing the data in this object.
        :rtype: Dict[str, Any]
        """
        key_values_ = _serialize(self.key_values)
        return {
            'keyValues': key_values_
        }

    def to_json(self) -> str:
        """
        Returns a JSON string representing the data in this object.

        :return: A JSON string representing the data in this object.
        :rtype: str
        """
        body_dict = self.to_dict()
        return json.dumps(body_dict, separators=(',', ':'))

    def to_body_bytes(self) -> bytes:
        """
        Returns a :class:`bytes` body representing the data in this object.

        :return: A :class:`bytes` body representing the data in this object.
        :rtype: bytes
        """
        body_json = self.to_json()
        return bytes(body_json, 'utf-8')

    def to_message(self, request_message: Optional[GenericMessage] = None) -> GenericMessage:
        """
        Returns a :class:`systemlink.messagebus.generic_message.GenericMessage`
        object representing the data in this object.

        :param request_message: Request message if this is a response.
        :type request_message: Optional[GenericMessage]
        :return: A :class:`systemlink.messagebus.generic_message.GenericMessage`
            object representing the data in this object.
        :rtype: GenericMessage
        """
        header = self.header
        if request_message:
            request_header = request_message.header
            header.correlation_id = request_header.correlation_id
            routing_key = MessageHeader.generate_routing_key(request_header.reply_to, self.MESSAGE_NAME)
            header.routing_key = routing_key
        body_bytes = self.to_body_bytes()
        return GenericMessage(header, body_bytes)

    @property
    def body_bytes(self) -> bytes:
        """
        Returns a :class:`bytes` body representing the data in this object.

        :return: A :class:`bytes` body representing the data in this object.
        :rtype: bytes
        """
        self._body = self.to_body_bytes()  # pylint: disable=attribute-defined-outside-init
        return self._body

    @body_bytes.setter
    def body_bytes(self, body_bytes: Optional[bytes]) -> None:  # pylint: disable=no-self-use,unused-argument
        """
        Set the raw message body.

        Not implemented. Do not use!

        :param body_bytes: The raw message body.
        :type body_bytes: Optional[bytes]
        """
        # This class method is defined simply because it is defined in
        # the base class.
        raise NotImplementedError("ConfigurationGetSectionKeyValuesResponse does not support setting 'body_bytes'")
