# -*- coding: utf-8 -*-
"""
Implementation of 'RequestMessage' class
"""
# Import python libs
import logging
from typing import Optional

# Import local libs
from systemlink.messagebus.message_base import MessageBase
from systemlink.messagebus.message_header import MessageHeader

# Set up logging
LOGGER = logging.getLogger(__name__)


class RequestMessage(MessageBase):  # pylint: disable=too-few-public-methods
    """
    Request Message

    A message meant to make a request so that a response may
    be returned.
    """
    def __init__(self, header: MessageHeader, body: Optional[bytes]) -> None:
        """
        :param header: The message header.
        :type header: MessageHeader
        :param body: The raw message body.
        :type body: Optional[bytes]
        """
        LOGGER.debug('RequestMessage __init__')
        super().__init__(
            header,
            body
        )
