# -*- coding: utf-8 -*-
"""
Implementation of 'RoutedMessage' class
"""
# Import python libs
from typing import Optional

# Import local libs
from systemlink.messagebus.message_base import MessageBase
from systemlink.messagebus.message_header import MessageHeader


class RoutedMessage(MessageBase):  # pylint: disable=too-few-public-methods
    """
    Routed Message

    A message meant to be routed by the given header.
    Defaults to ignore responses.
    """
    def __init__(self, header: MessageHeader, body: Optional[bytes]) -> None:
        """
        :param header: The message header.
        :type header: MessageHeader
        :param body: The raw message body.
        :type body: Optional[bytes]
        """
        if header:
            header.ignore_response = True
        super().__init__(
            header,
            body
        )
