# -*- coding: utf-8 -*-
"""
Contains workspace related helpers.
"""
from typing import List

from systemlink.messagebus.auth.user_services_client import UserServicesClient


def translate_ids_to_names(ids: List[str], api_key: str) -> List[str]:
    """
    Translates workspace ids to workspace names.

    :param ids: The workspace ids used to get the workspace names.
    :type ids: List[str]
    :param api_key: The key used to call the authentication route.
    :type api_key: str
    :return: The workspace names.
    :rtype: List[str]
    """
    user_client = UserServicesClient()
    auth_result = user_client.auth(api_key=api_key)
    workspaces = auth_result.workspaces
    workspace_id_to_name_map = {workspace.id: workspace.name for workspace in workspaces}
    return [workspace_id_to_name_map.get(workspace_id, workspace_id) for workspace_id in ids]
