# -*- coding: utf-8 -*-
"""
Registration of error codes to the Error Code Registry.
"""
from __future__ import absolute_import

# Import local libs
# pylint: disable=import-error
from systemlink.messagebus import error_code_registry
# pylint: enable=import-error

# This will register the following error codes:
#   Skyline.InternalServiceError [-251000]
#   Skyline.RequestTimedOut [-251001]
#   Skyline.IOError [-251002]
#   Skyline.OutOfMemory [-251003]
#   Skyline.Exception [-251004]
#   Skyline.FailedToParse [-251005]
#   Skyline.InvalidSemaphoreInitialization [-251006]
#   Skyline.InsufficientResources [-251007]
#   Skyline.NotSupported [-251008]
#   Skyline.InsufficientPrivileges [-251009]
#   Skyline.MultipleInitializations [-251010]
#   Skyline.NoSkylineConfigurations [-251011]
#   Skyline.ConfigDirectoryNotFound [-251012]
#   Skyline.DuplicateConfigurationId [-251013]
#   Skyline.EndOfStream [-251014]
#   Skyline.QueueEmpty [-251015]
#   Skyline.FailedToInitializeNISSL [-251016]
#   Skyline.AMQPErrorOpeningTCPConnection [-251017]
#   Skyline.AMQPErrorClosingTCPConnection [-251018]
#   Skyline.AMQPErrorEndingTCPConnection [-251019]
#   Skyline.AMQPErrorCreatingTCPSocket [-251020]
#   Skyline.AMQPErrorCreatingSSLSocket [-251021]
#   Skyline.AMQPErrorOpeningSocket [-251022]
#   Skyline.AMQPErrorSettingCACertificate [-251023]
#   Skyline.AMQPErrorFailedToLogIn [-251024]
#   Skyline.AMQPErrorOpeningChannel [-251025]
#   Skyline.AMQPErrorDeclaringQueue [-251026]
#   Skyline.AMQPErrorObtainingQueueName [-251027]
#   Skyline.AMQPErrorBindingQueue [-251028]
#   Skyline.AMQPErrorUnbindingQueue [-251029]
#   Skyline.AMQPErrorDeclaringExchange [-251030]
#   Skyline.AMQPErrorPerformingBasicConsume [-251031]
#   Skyline.AMQPErrorPublishingMessage [-251032]
#   Skyline.AMQPErrorDequeueingMessage [-251033]
#   Skyline.AMQPErrorCertificateExpired [-251034]
#   Skyline.AMQPErrorPeerVerifyFailed [-251035]
#   Skyline.FailedToLoadCertificate [-251036]
#   Skyline.UnexpectedException [-251037]
#   Skyline.NotFound [-251038]
#   Skyline.UnableToLoadClientLibrary [-251039]
#   Skyline.AMQPErrorSettingQoS [-251040]
#   Skyline.OneOrMoreErrorsOccurred [-251041]
#   Skyline.OperationCanceled [-251044]
#   Skyline.DataDowngradeUnsupported [-251045]
#   Skyline.UnknownWorkspace [-251048]
#   Skyline.ResourceUnauthorized [-251049]
#   Skyline.CouldNotPerformOperation [-251050]
#   Skyline.WorkspaceDisabled [-251051]
#   FileIngestion.InvalidFileId [-251600]
#   FileIngestion.InvalidSession [-251601]
#   FileIngestion.InvalidEventReference [-251602]
#   FileIngestion.InvalidProperty [-251603]
#   FileIngestion.PropertyDoesNotExist [-251604]
#   FileIngestion.InvalidState [-251605]
#   FileIngestion.DuplicateId [-251606]
#   FileIngestion.DuplicatePacket [-251607]
#   FileIngestion.IdNotFound [-251608]
#   FileIngestion.InvalidIdFormat [-251609]
#   FileIngestion.MissingPacket [-251610]
#   FileIngestion.ErrorOpeningFile [-251611]
#   FileIngestion.ErrorAccessingMetadata [-251612]
#   FileIngestion.CouldNotLocateFile [-251613]
#   FileIngestion.ErrorDeletingFile [-251614]
#   FileIngestion.ErrorDeletingMetadata [-251615]
#   FileIngestion.Unauthorized [-251616]
#   FileIngestion.MalformedDatabaseEntry [-251617]
#   FileIngestion.AbortingTransmissionNoResponse [-251618]
#   FileIngestion.AbortingTransmissionError [-251619]
#   FileIngestion.ErrorTransmittingFile [-251620]
#   FileIngestion.PresumedAbandoned [-251621]
#   FileIngestion.MaxSizeExceeded [-251622]
#   FileIngestion.InvalidPacketSize [-251623]
#   FileIngestion.MismatchedFileSize [-251624]
#   FileIngestion.UnsupportedQueryOperator [-251625]
#   FileIngestion.QueryEntryKeyCannotBeNullOrEmpty [-251626]
#   FileIngestion.QueryEntryValueCannotBeNull [-251627]
#   FileIngestion.PacketEventConfigurationMismatch [-251628]
#   FileIngestion.ValueCannotBeNegative [-251629]
#   FileIngestion.InvalidMetadataPart [-251630]
#   FileIngestion.MalformedRequest [-251631]
#   FileIngestion.MetadataRevisionMismatch [-251632]
#   FileIngestion.ErrorUpdatingMetadata [-251633]
#   FileIngestion.ErrorUploadingToAmazon [-251635]
#   FileIngestion.ErrorDeletingMultipleFiles [-251637]
#   FileIngestion.ErrorUploadingToAmazonBucket [-251638]
#   SkylineWebServices.MethodNotAllowed [-252200]
#   SkylineWebServices.SkipMustBePositive [-252201]
#   SkylineWebServices.TakeMustBePositive [-252202]
#   SkylineWebServices.MalformedProperty [-252203]
#   SkylineWebServices.MalformedJsonRequestBody [-252204]
#   SkylineWebServices.MissingRequiredJsonKey [-252205]
#   SkylineWebServices.InvalidJsonValueForKey [-252206]
#   SkylineWebServices.InvalidJsonDataTypeForKey [-252207]
#   SkylineWebServices.NoQueryParameterSpecified [-252208]
#   SkylineWebServices.UnknownQueryParameter [-252209]
#   SkylineWebServices.InvalidQueryParameter [-252210]
#   SkylineWebServices.MustSelectAFileForUpload [-252211]
#   SkylineWebServices.EmptyRequestBody [-252212]
#   SkylineWebServices.InvalidJsonDataTypeForElementInKey [-252213]
#   SkylineWebServices.InvalidJsonValueForElementInKey [-252214]
#   SkylineWebServices.NoElementsInJsonArray [-252215]
#   SkylineWebServices.ErrorParsingRequest [-252216]
#   SkylineWebServices.NotFound [-252217]
#   SkylineWebServices.InvalidValueForQueryParameter [-252218]
#   SkylineWebServices.MissingHandlerForUri [-252219]
#   SkylineWebServices.InvalidHandlerForUri [-252220]
#   SkylineWebServices.MissingRequiredUriParameter [-252221]
#   SkylineWebServices.UnexpectedMultipartBody [-252222]
#   SkylineWebServices.TimeoutReadingRequest [-252223]
#   SkylineWebServices.TimeoutSendingResponse [-252224]
#   SkylineWebServices.ErrorHandlingRequest [-252225]
#   SkylineWebServices.MalformedRequestEncoding [-252226]
#   SkylineWebServices.HttpStreamAborted [-252227]
#   SkylineWebServices.RequestDataTooLarge [-252228]
#   SkylineWebServices.Unauthorized [-252229]
#   TDMReader.FileServiceFailed [-253500]
#   TDMReader.FileServiceError [-253501]
#   TDMReader.DownloadTimedOut [-253502]
#   TDMReader.DownloadFailed [-253503]
#   TDMReader.IllegalValue [-253504]
#   TDMReader.BadValue [-253505]
#   TDMReader.ChannelNotFound [-253506]
#   TDMReader.GroupNotFound [-253507]
#   TDMReader.InvalidIdFormat [-253508]
#   TDMReader.UnknownIdService [-253509]
#   TDMReader.UnableToOpenFile [-253510]
#   TDMReader.XAndYDifferentLengths [-253511]
#   TDMReader.FilterError [-253512]
#   TDMReader.FilterChannelsHaveDifferentLengths [-253513]
#   TDMReader.FileNotFound [-253514]
#   TDMReader.IncompatibleDataType [-253515]
#   TDMReader.NoMoreGroupsToRead [-253516]
#   TDMReader.NoMoreChannelDataToRead [-253517]
#   TDMReader.MismatchedOutputObjectNames [-253518]
#   TDMReader.UnableToUploadResults [-253519]
#   TDMReader.DataFinderError [-253520]

REGISTERED = False


def register_error_codes():  # pylint: disable=too-many-statements
    """
    Register error codes to the Error Code Registry.
    """
    # pylint: disable=line-too-long
    global REGISTERED  # pylint: disable=global-statement

    if REGISTERED:
        return

    # Right now we only support English.
    # Once we support more, use "locale.getdefaultlocale" to get the
    # system language.
    language = 'eng'

    if language == 'eng':
        error_code_registry.register(
            "Skyline",
            "InternalServiceError",
            "Internal Skyline service error.",
            -251000
        )
        error_code_registry.register(
            "Skyline",
            "RequestTimedOut",
            "Request timed out.",
            -251001
        )
        error_code_registry.register(
            "Skyline",
            "IOError",
            "I/O error.",
            -251002
        )
        error_code_registry.register(
            "Skyline",
            "OutOfMemory",
            "Out of memory.",
            -251003
        )
        error_code_registry.register(
            "Skyline",
            "Exception",
            "Skyline exception.",
            -251004
        )
        error_code_registry.register(
            "Skyline",
            "FailedToParse",
            "Failed to parse.",
            -251005
        )
        error_code_registry.register(
            "Skyline",
            "InvalidSemaphoreInitialization",
            "Invalid semaphore initialization.",
            -251006
        )
        error_code_registry.register(
            "Skyline",
            "InsufficientResources",
            "Insufficient resources.",
            -251007
        )
        error_code_registry.register(
            "Skyline",
            "NotSupported",
            "Not supported.",
            -251008
        )
        error_code_registry.register(
            "Skyline",
            "InsufficientPrivileges",
            "Insufficient privileges.",
            -251009
        )
        error_code_registry.register(
            "Skyline",
            "MultipleInitializations",
            "Attempt to reinitialize with multiple configurations.",
            -251010
        )
        error_code_registry.register(
            "Skyline",
            "NoSkylineConfigurations",
            "No Skyline configurations available.",
            -251011
        )
        error_code_registry.register(
            "Skyline",
            "ConfigDirectoryNotFound",
            "Skyline configurations directory not found.",
            -251012
        )
        error_code_registry.register(
            "Skyline",
            "DuplicateConfigurationId",
            "Duplicate configuration id.",
            -251013
        )
        error_code_registry.register(
            "Skyline",
            "EndOfStream",
            "End of stream.",
            -251014
        )
        error_code_registry.register(
            "Skyline",
            "QueueEmpty",
            "Queue empty.",
            -251015
        )
        error_code_registry.register(
            "Skyline",
            "FailedToInitializeNISSL",
            "Failed to initialize NI SSL.",
            -251016
        )
        error_code_registry.register(
            "Skyline",
            "AMQPErrorOpeningTCPConnection",
            "AMQP error: Failed to open TCP connection.",
            -251017
        )
        error_code_registry.register(
            "Skyline",
            "AMQPErrorClosingTCPConnection",
            "AMQP error: Failed to close TCP connection.",
            -251018
        )
        error_code_registry.register(
            "Skyline",
            "AMQPErrorEndingTCPConnection",
            "AMQP error: Failed to end TCP connection.",
            -251019
        )
        error_code_registry.register(
            "Skyline",
            "AMQPErrorCreatingTCPSocket",
            "AMQP error: Failed to create TCP socket.",
            -251020
        )
        error_code_registry.register(
            "Skyline",
            "AMQPErrorCreatingSSLSocket",
            "AMQP error: Failed to create SSL socket.",
            -251021
        )
        error_code_registry.register(
            "Skyline",
            "AMQPErrorOpeningSocket",
            "AMQP error: Failed to open socket.",
            -251022
        )
        error_code_registry.register(
            "Skyline",
            "AMQPErrorSettingCACertificate",
            "AMQP error: Failed to set CA certificate.",
            -251023
        )
        error_code_registry.register(
            "Skyline",
            "AMQPErrorFailedToLogIn",
            "AMQP error: Failed to log in.",
            -251024
        )
        error_code_registry.register(
            "Skyline",
            "AMQPErrorOpeningChannel",
            "AMQP error: Failed to open channel.",
            -251025
        )
        error_code_registry.register(
            "Skyline",
            "AMQPErrorDeclaringQueue",
            "AMQP error: Failed to declare queue.",
            -251026
        )
        error_code_registry.register(
            "Skyline",
            "AMQPErrorObtainingQueueName",
            "AMQP error: Failed to obtain queue name.",
            -251027
        )
        error_code_registry.register(
            "Skyline",
            "AMQPErrorBindingQueue",
            "AMQP error: Failed to bind queue.",
            -251028
        )
        error_code_registry.register(
            "Skyline",
            "AMQPErrorUnbindingQueue",
            "AMQP error: Failed to unbind queue.",
            -251029
        )
        error_code_registry.register(
            "Skyline",
            "AMQPErrorDeclaringExchange",
            "AMQP error: Failed to declare exchange.",
            -251030
        )
        error_code_registry.register(
            "Skyline",
            "AMQPErrorPerformingBasicConsume",
            "AMQP error: Failed to perform basic consume.",
            -251031
        )
        error_code_registry.register(
            "Skyline",
            "AMQPErrorPublishingMessage",
            "AMQP error: Failed to publish message.",
            -251032
        )
        error_code_registry.register(
            "Skyline",
            "AMQPErrorDequeueingMessage",
            "AMQP error: Failed to dequeue message.",
            -251033
        )
        error_code_registry.register(
            "Skyline",
            "AMQPErrorCertificateExpired",
            "AMQP error: Cetificate expired.",
            -251034
        )
        error_code_registry.register(
            "Skyline",
            "AMQPErrorPeerVerifyFailed",
            "AMQP error: Peer verify failed.",
            -251035
        )
        error_code_registry.register(
            "Skyline",
            "FailedToLoadCertificate",
            "Failed to load certificate.",
            -251036
        )
        error_code_registry.register(
            "Skyline",
            "UnexpectedException",
            "An unexpected exception occurred: {0}",
            -251037
        )
        error_code_registry.register(
            "Skyline",
            "NotFound",
            "Not found.",
            -251038
        )
        error_code_registry.register(
            "Skyline",
            "UnableToLoadClientLibrary",
            "Unable to load a client library. Ensure the NI SystemLink Client is installed.",
            -251039
        )
        error_code_registry.register(
            "Skyline",
            "AMQPErrorSettingQoS",
            "AMQP error: Failed to set quality of service.",
            -251040
        )
        error_code_registry.register(
            "Skyline",
            "OneOrMoreErrorsOccurred",
            "One or more errors occurred. See the contained list for details of each error.",
            -251041
        )
        error_code_registry.register(
            "Skyline",
            "OperationCanceled",
            "The requested operation was canceled.",
            -251044
        )
        error_code_registry.register(
            "Skyline",
            "DataDowngradeUnsupported",
            "Data downgrades are not supported. Please revert the service to a newer version.",
            -251045
        )
        error_code_registry.register(
            "Skyline",
            "UnknownWorkspace",
            "Workspace '{0}' does not exist.",
            -251048
        )
        error_code_registry.register(
            "Skyline",
            "ResourceUnauthorized",
            "Not authorized to operate on resource {0}.",
            -251049
        )
        error_code_registry.register(
            "Skyline",
            "CouldNotPerformOperation",
            "Could not perform operation on resource {0}.",
            -251050
        )
        error_code_registry.register(
            "Skyline",
            "WorkspaceDisabled",
            "Cannot perform operation on resource in archived workspace '{0}'.",
            -251051
        )
        error_code_registry.register(
            "FileIngestion",
            "InvalidFileId",
            "Invalid file id.",
            -251600
        )
        error_code_registry.register(
            "FileIngestion",
            "InvalidSession",
            "Invalid session.",
            -251601
        )
        error_code_registry.register(
            "FileIngestion",
            "InvalidEventReference",
            "Invalid event reference.",
            -251602
        )
        error_code_registry.register(
            "FileIngestion",
            "InvalidProperty",
            "Invalid property.",
            -251603
        )
        error_code_registry.register(
            "FileIngestion",
            "PropertyDoesNotExist",
            "Property does not exist.",
            -251604
        )
        error_code_registry.register(
            "FileIngestion",
            "InvalidState",
            "Invalid state.",
            -251605
        )
        error_code_registry.register(
            "FileIngestion",
            "DuplicateId",
            "File with id '{0}' already exists.",
            -251606
        )
        error_code_registry.register(
            "FileIngestion",
            "DuplicatePacket",
            "Duplicate packet {0} for file id '{1}'.",
            -251607
        )
        error_code_registry.register(
            "FileIngestion",
            "IdNotFound",
            "File with id '{0}' not found.",
            -251608
        )
        error_code_registry.register(
            "FileIngestion",
            "InvalidIdFormat",
            "Invalid id format: '{0}'.",
            -251609
        )
        error_code_registry.register(
            "FileIngestion",
            "MissingPacket",
            "Missing packet: {0}.",
            -251610
        )
        error_code_registry.register(
            "FileIngestion",
            "ErrorOpeningFile",
            "Error opening file: '{0}'.",
            -251611
        )
        error_code_registry.register(
            "FileIngestion",
            "ErrorAccessingMetadata",
            "Error opening metadata for file: '{0}'.",
            -251612
        )
        error_code_registry.register(
            "FileIngestion",
            "CouldNotLocateFile",
            "Could not locate file: '{0}'.",
            -251613
        )
        error_code_registry.register(
            "FileIngestion",
            "ErrorDeletingFile",
            "Error deleting file: '{0}'.",
            -251614
        )
        error_code_registry.register(
            "FileIngestion",
            "ErrorDeletingMetadata",
            "Error deleting metadata for file: '{0}'.",
            -251615
        )
        error_code_registry.register(
            "FileIngestion",
            "Unauthorized",
            "Unauthorized to access file: '{0}'.",
            -251616
        )
        error_code_registry.register(
            "FileIngestion",
            "MalformedDatabaseEntry",
            "Malformed database entry.",
            -251617
        )
        error_code_registry.register(
            "FileIngestion",
            "AbortingTransmissionNoResponse",
            "Aborting transmission because the requester failed to respond.",
            -251618
        )
        error_code_registry.register(
            "FileIngestion",
            "AbortingTransmissionError",
            "Aborting transmission because the requester responded with an error.",
            -251619
        )
        error_code_registry.register(
            "FileIngestion",
            "ErrorTransmittingFile",
            "Error transmitting file.",
            -251620
        )
        error_code_registry.register(
            "FileIngestion",
            "PresumedAbandoned",
            "File '{0}' has made no progress in {1} minutes and is presumed abandoned.",
            -251621
        )
        error_code_registry.register(
            "FileIngestion",
            "MaxSizeExceeded",
            "Packet {0} causes file to exceed maximum size of {1} bytes.",
            -251622
        )
        error_code_registry.register(
            "FileIngestion",
            "InvalidPacketSize",
            "Packet size invalid: {0}.",
            -251623
        )
        error_code_registry.register(
            "FileIngestion",
            "MismatchedFileSize",
            "Size of file '{0}' on disk does not match metadata.",
            -251624
        )
        error_code_registry.register(
            "FileIngestion",
            "UnsupportedQueryOperator",
            "Unsupported query operator: {0}.",
            -251625
        )
        error_code_registry.register(
            "FileIngestion",
            "QueryEntryKeyCannotBeNullOrEmpty",
            "Query entry key cannot be null or empty.",
            -251626
        )
        error_code_registry.register(
            "FileIngestion",
            "QueryEntryValueCannotBeNull",
            "Query entry value cannot be null.",
            -251627
        )
        error_code_registry.register(
            "FileIngestion",
            "PacketEventConfigurationMismatch",
            "File cannot use this packet event instance because it was created with a different configuration.",
            -251628
        )
        error_code_registry.register(
            "FileIngestion",
            "ValueCannotBeNegative",
            "The value cannot be negative.",
            -251629
        )
        error_code_registry.register(
            "FileIngestion",
            "InvalidMetadataPart",
            "Invalid metadata part.",
            -251630
        )
        error_code_registry.register(
            "FileIngestion",
            "MalformedRequest",
            "The HTTP request doesn't match the endpoint API.",
            -251631
        )
        error_code_registry.register(
            "FileIngestion",
            "MetadataRevisionMismatch",
            "The provided expected revision doesn't match the revision on the server: {0}.",
            -251632
        )
        error_code_registry.register(
            "FileIngestion",
            "ErrorUpdatingMetadata",
            "Error updating metadata for file id '{0}'.",
            -251633
        )
        error_code_registry.register(
            "FileIngestion",
            "ErrorUploadingToAmazon",
            "File couldn't be uploaded to Amazon S3. Amazon error code: '{0}'.",
            -251635
        )
        error_code_registry.register(
            "FileIngestion",
            "ErrorDeletingMultipleFiles",
            "The request to delete files failed partially. One or more files couldn't be deleted.",
            -251637
        )
        error_code_registry.register(
            "FileIngestion",
            "ErrorUploadingToAmazonBucket",
            "File couldn't be uploaded to Amazon S3. Amazon error code: '{0}' - Bucket name: {1}.",
            -251638
        )
        error_code_registry.register(
            "SkylineWebServices",
            "MethodNotAllowed",
            "Method '{0}' not allowed.",
            -252200
        )
        error_code_registry.register(
            "SkylineWebServices",
            "SkipMustBePositive",
            "Skip must be a positive integer.",
            -252201
        )
        error_code_registry.register(
            "SkylineWebServices",
            "TakeMustBePositive",
            "Take must be a positive integer.",
            -252202
        )
        error_code_registry.register(
            "SkylineWebServices",
            "MalformedProperty",
            "Malformed property: '{0}'.",
            -252203
        )
        error_code_registry.register(
            "SkylineWebServices",
            "MalformedJsonRequestBody",
            "Malformed JSON request body.",
            -252204
        )
        error_code_registry.register(
            "SkylineWebServices",
            "MissingRequiredJsonKey",
            "Missing required JSON key: '{0}'.",
            -252205
        )
        error_code_registry.register(
            "SkylineWebServices",
            "InvalidJsonValueForKey",
            "Invalid JSON value for key '{0}'.",
            -252206
        )
        error_code_registry.register(
            "SkylineWebServices",
            "InvalidJsonDataTypeForKey",
            "Invalid JSON data type for for key '{0}'.",
            -252207
        )
        error_code_registry.register(
            "SkylineWebServices",
            "NoQueryParameterSpecified",
            "No query parameter specified.",
            -252208
        )
        error_code_registry.register(
            "SkylineWebServices",
            "UnknownQueryParameter",
            "Unknown query parameter: '{0}'.",
            -252209
        )
        error_code_registry.register(
            "SkylineWebServices",
            "InvalidQueryParameter",
            "Invalid '{0}' query parameter.",
            -252210
        )
        error_code_registry.register(
            "SkylineWebServices",
            "MustSelectAFileForUpload",
            "Must select a file for upload.",
            -252211
        )
        error_code_registry.register(
            "SkylineWebServices",
            "EmptyRequestBody",
            "Empty request body.",
            -252212
        )
        error_code_registry.register(
            "SkylineWebServices",
            "InvalidJsonDataTypeForElementInKey",
            "Invalid JSON data type for element in key '{0}'.",
            -252213
        )
        error_code_registry.register(
            "SkylineWebServices",
            "InvalidJsonValueForElementInKey",
            "Invalid JSON value for element in key '{0}'.",
            -252214
        )
        error_code_registry.register(
            "SkylineWebServices",
            "NoElementsInJsonArray",
            "At least one element must be provided in the JSON array '{0}'.",
            -252215
        )
        error_code_registry.register(
            "SkylineWebServices",
            "ErrorParsingRequest",
            "An error occurred while parsing the JSON request body: '{0}'.",
            -252216
        )
        error_code_registry.register(
            "SkylineWebServices",
            "NotFound",
            "The requested URI was not found.",
            -252217
        )
        error_code_registry.register(
            "SkylineWebServices",
            "InvalidValueForQueryParameter",
            "Invalid value for query parameter: '{0}'.",
            -252218
        )
        error_code_registry.register(
            "SkylineWebServices",
            "MissingHandlerForUri",
            "The handler for the requested URI is not available.",
            -252219
        )
        error_code_registry.register(
            "SkylineWebServices",
            "InvalidHandlerForUri",
            "The handler for the requested URI is invalid.",
            -252220
        )
        error_code_registry.register(
            "SkylineWebServices",
            "MissingRequiredUriParameter",
            "Missing required URI parameter: '{0}'.",
            -252221
        )
        error_code_registry.register(
            "SkylineWebServices",
            "UnexpectedMultipartBody",
            "Unexpected multipart/form-data request body.",
            -252222
        )
        error_code_registry.register(
            "SkylineWebServices",
            "TimeoutReadingRequest",
            "Time out reading request body.",
            -252223
        )
        error_code_registry.register(
            "SkylineWebServices",
            "TimeoutSendingResponse",
            "Time out writing response body.",
            -252224
        )
        error_code_registry.register(
            "SkylineWebServices",
            "ErrorHandlingRequest",
            "Error handling request.",
            -252225
        )
        error_code_registry.register(
            "SkylineWebServices",
            "MalformedRequestEncoding",
            "Malformed UTF-8 request body.",
            -252226
        )
        error_code_registry.register(
            "SkylineWebServices",
            "HttpStreamAborted",
            "HTTP stream was aborted.",
            -252227
        )
        error_code_registry.register(
            "SkylineWebServices",
            "RequestDataTooLarge",
            "HTTP request data is too large to buffer.",
            -252228
        )
        error_code_registry.register(
            "SkylineWebServices",
            "Unauthorized",
            "User is not authorized.",
            -252229
        )
        error_code_registry.register(
            "TDMReader",
            "FileServiceFailed",
            "File service failed.",
            -253500
        )
        error_code_registry.register(
            "TDMReader",
            "FileServiceError",
            "File service responded with error: '{0}'.",
            -253501
        )
        error_code_registry.register(
            "TDMReader",
            "DownloadTimedOut",
            "Download of file timed out: '{0}'.",
            -253502
        )
        error_code_registry.register(
            "TDMReader",
            "DownloadFailed",
            "Download of file failed: '{0}'.",
            -253503
        )
        error_code_registry.register(
            "TDMReader",
            "IllegalValue",
            "Illegal value for: '{0}'.",
            -253504
        )
        error_code_registry.register(
            "TDMReader",
            "BadValue",
            "Bad value for: '{0}'.",
            -253505
        )
        error_code_registry.register(
            "TDMReader",
            "ChannelNotFound",
            "Channel not found: '{0}'.",
            -253506
        )
        error_code_registry.register(
            "TDMReader",
            "GroupNotFound",
            "Group not found: '{0}'.",
            -253507
        )
        error_code_registry.register(
            "TDMReader",
            "InvalidIdFormat",
            "Invalid id format: '{0}'.",
            -253508
        )
        error_code_registry.register(
            "TDMReader",
            "UnknownIdService",
            "Invalid id service: '{0}'.",
            -253509
        )
        error_code_registry.register(
            "TDMReader",
            "UnableToOpenFile",
            "Unable to open file '{0}' with data plugin '{1}'.",
            -253510
        )
        error_code_registry.register(
            "TDMReader",
            "XAndYDifferentLengths",
            "X and Y channels have different lengths.",
            -253511
        )
        error_code_registry.register(
            "TDMReader",
            "FilterError",
            "Filter error '{0}'.",
            -253512
        )
        error_code_registry.register(
            "TDMReader",
            "FilterChannelsHaveDifferentLengths",
            "Filter channels have different lengths.",
            -253513
        )
        error_code_registry.register(
            "TDMReader",
            "FileNotFound",
            "File not found: '{0}'.",
            -253514
        )
        error_code_registry.register(
            "TDMReader",
            "IncompatibleDataType",
            "Incompatible data type for channel '{0}'. Channel data type is '{1}'. Requested data type is '{2}'.",
            -253515
        )
        error_code_registry.register(
            "TDMReader",
            "NoMoreGroupsToRead",
            "No more groups to read.",
            -253516
        )
        error_code_registry.register(
            "TDMReader",
            "NoMoreChannelDataToRead",
            "No more data to read for channel(s).",
            -253517
        )
        error_code_registry.register(
            "TDMReader",
            "MismatchedOutputObjectNames",
            "Count of OutputObjectNames and returned channels do not match.",
            -253518
        )
        error_code_registry.register(
            "TDMReader",
            "UnableToUploadResults",
            "Failure uploading results.",
            -253519
        )
        error_code_registry.register(
            "TDMReader",
            "DataFinderError",
            "DataFinder responded with error: '{0}'.",
            -253520
        )

    # pylint: enable=line-too-long
    REGISTERED = True
